@@ -5,7 +5,7 @@
 // Author      : Avi
 // Revision    : $Revision: #24 $ 
 //
-// Copyright 2009-2020 ECMWF.
+// Copyright 2009- ECMWF.
 // This software is licensed under the terms of the Apache Licence version 2.0 
 // which can be obtained at http://www.apache.org/licenses/LICENSE-2.0. 
 // In applying this licence, ECMWF does not waive the privileges and immunities 
@@ -259,7 +259,15 @@ BOOST_AUTO_TEST_CASE( test_AutoArchiveAttr_serialisation )
       doSaveAndRestore(fileName,saved);
    }
    {
-      AutoArchiveAttr saved( TimeSlot(12,10), true) ;
+      AutoArchiveAttr saved(100,true/*idle*/);
+      doSaveAndRestore(fileName,saved);
+   }
+   {
+      AutoArchiveAttr saved( TimeSlot(12,10), true, false/*idle*/) ;
+      doSaveAndRestore(fileName,saved);
+   }
+   {
+      AutoArchiveAttr saved( TimeSlot(12,10), true, true/*idle*/) ;
       doSaveAndRestore(fileName,saved);
    }
 }
