@@ -3,7 +3,7 @@
 // Author      : Avi
 // Revision    : $Revision: #64 $ 
 //
-// Copyright 2009-2020 ECMWF.
+// Copyright 2009- ECMWF.
 // This software is licensed under the terms of the Apache Licence version 2.0 
 // which can be obtained at http://www.apache.org/licenses/LICENSE-2.0. 
 // In applying this licence, ECMWF does not waive the privileges and immunities 
@@ -183,6 +183,16 @@ void Family::gen_variables(std::vector<Variable>& vec) const
    NodeContainer::gen_variables(vec);
 }
 
+std::string Family::find_node_path(const std::string& type, const std::string& node_name) const
+{
+   if (Str::caseInsCompare(type,"family")) {
+      if (node_name == name()) {
+         return absNodePath();
+      }
+   }
+   return NodeContainer::find_node_path(type,node_name);
+}
+
 // ================================================================
 
 FamGenVariables::FamGenVariables(const Family* f)
