@@ -6,7 +6,7 @@
 // Author      : Avi
 // Revision    : $Revision: #88 $ 
 //
-// Copyright 2009-2020 ECMWF.
+// Copyright 2009- ECMWF.
 // This software is licensed under the terms of the Apache Licence version 2.0 
 // which can be obtained at http://www.apache.org/licenses/LICENSE-2.0. 
 // In applying this licence, ECMWF does not waive the privileges and immunities 
@@ -74,6 +74,9 @@ public:
    node_ptr find_by_name(const std::string& name) const;
 	family_ptr findFamily(const std::string& familyName) const;
 	task_ptr findTask(const std::string& taskName) const;
+
+   std::string find_node_path(const std::string& type, const std::string& name) const override;
+
 	void getAllFamilies(std::vector<Family*>&) const;
 	void getAllNodes(std::vector<Node*>&) const override;
    void getAllTasks(std::vector<Task*>&) const override;
@@ -110,8 +113,10 @@ public:
    void update_limits() override;
    void sort_attributes(ecf::Attr::Type attr,bool recursive = true,const std::vector<std::string>& no_sort = std::vector<std::string>()) override;
 
+   bool has_archive() const override;
    void archive();
    void restore();
+   void remove_archived_files(); // used in delete
    std::string archive_path() const; //can throw if ECF_HOME not defined
 
    boost::posix_time::time_duration sum_runtime() override;
