@@ -3,7 +3,7 @@
 // Author      : Avi
 // Revision    : $Revision: #204 $ 
 //
-// Copyright 2009-2020 ECMWF.
+// Copyright 2009- ECMWF.
 // This software is licensed under the terms of the Apache Licence version 2.0 
 // which can be obtained at http://www.apache.org/licenses/LICENSE-2.0. 
 // In applying this licence, ECMWF does not waive the privileges and immunities 
@@ -320,6 +320,16 @@ node_ptr Task::find_immediate_child(const boost::string_view& name) const
 	return node_ptr();
 }
 
+std::string Task::find_node_path(const std::string& type, const std::string& node_name) const
+{
+   if (Str::caseInsCompare(type,"task")) {
+      if (node_name == name()) {
+         return absNodePath();
+      }
+   }
+   return string();
+}
+
 void Task::reset()
 {
    if (aliases_.empty()) {
@@ -522,7 +532,7 @@ bool Task::resolveDependencies(JobsParam& jobsParam)
             }
          }
          catch ( boost::bad_lexical_cast& ) {
-            LOG(Log::ERR,"Variable ECF_TRIES must be convertible to an integer. Can not resubmit job for task:" << absNodePath());
+            LOG(Log::ERR,"Variable ECF_TRIES must be convertible to an integer. Cannot resubmit job for task:" << absNodePath());
             return false;
          }
       }
@@ -655,7 +665,7 @@ bool Task::addChild( const node_ptr&, size_t)
 bool Task::isAddChildOk( Node*, std::string& errorMsg) const
 {
    // Only used during PLUG: aliases can't be plugged.
-	errorMsg += "Can not add children to a task node.";
+	errorMsg += "Cannot add children to a task node.";
 	return false;
 }
 
