@@ -1,5 +1,5 @@
 #!/usr/bin/env python
-#////////1/////////2/////////3/////////4/////////5/////////6/////////7/////////8
+# ////////1/////////2/////////3/////////4/////////5/////////6/////////7/////////8
 # Name        :
 # Author      : Avi
 # Revision    : $Revision: #10 $
@@ -10,8 +10,8 @@
 # In applying this licence, ECMWF does not waive the privileges and immunities
 # granted to it by virtue of its status as an intergovernmental organisation
 # nor does it submit to any jurisdiction.
-#////////1/////////2/////////3/////////4/////////5/////////6/////////7/////////8
-from __future__ import print_function
+# ////////1/////////2/////////3/////////4/////////5/////////6/////////7/////////8
+
 # -m trace --count -C .
 """an example for a simple python client to help ecFlow scheduling
  + unit test
@@ -47,9 +47,10 @@ import time
 import unittest
 from time import gmtime, strftime
 
-ECFLOWP = "/usr/local/apps/ecflow/current"
-ECFLOWC = ECFLOWP + "/bin/ecflow_client "
-sys.path.append(ECFLOWP + "/lib/python2.7/site-packages/ecflow")
+# ECFLOWP = "/usr/local/apps/ecflow/current"
+# ECFLOWC = ECFLOWP + "/bin/ecflow_client "
+# sys.path.append(ECFLOWP + "/lib/python2.7/site-packages/ecflow")
+ECFLOWC = "ecflow_client "
 child = None
 
 
@@ -74,6 +75,7 @@ def excepthook(exctype, value, traceback):
 def fullname(item):
     return ""
 
+
 sys.excepthook = excepthook
 from ecf import *  # mirror
 import ecf
@@ -88,27 +90,33 @@ DEBUG = 0
 USER = "emos"
 # USER = "map"
 
-sms_status = {-1: "unknown",
-              0: "unknown",
-              1: "suspended",
-              2: "complete",
-              3: "queued",
-              4: "submitted",
-              5: "active",
-              6: "aborted",
-              7: "shutdown",
-              8: "halted",
-              9: "unknown", }
-sms_type = {13: "definition",
-            12: "suite",
-            11: "family",
-            10: "task",
-            32: "alias", }
+sms_status = {
+    -1: "unknown",
+    0: "unknown",
+    1: "suspended",
+    2: "complete",
+    3: "queued",
+    4: "submitted",
+    5: "active",
+    6: "aborted",
+    7: "shutdown",
+    8: "halted",
+    9: "unknown",
+}
+sms_type = {
+    13: "definition",
+    12: "suite",
+    11: "family",
+    10: "task",
+    32: "alias",
+}
 
 
 ############################
 def usage():
-    print(sys.argv[0], """
+    print(
+        sys.argv[0],
+        """
       -h # help
       -m <server@port> # mirror path fri
       -t # unit test
@@ -118,7 +126,8 @@ def usage():
 
 can also be used as a module: gen_task, gen_suite
 
-    """)
+    """,
+    )
     for num, val in enumerate(sys.argv):
         print(num, val)
     child.report("abort")
@@ -133,28 +142,31 @@ def get_uid():
 ############################
 def gen_task(var=True, load_only=False, kind=None):
     from ecf import Task, Label, Variables
+
     pwd = os.getcwd()
     name = sys.argv[0]
-    if '/' in name:
-        name = name.split('/')[-1]
-    if '.' in name:
-        name = name.split('.')[0]
+    if "/" in name:
+        name = name.split("/")[-1]
+    if "." in name:
+        name = name.split(".")[0]
     rec = "00:30"
     cmd = "/home/ma/emos/bin/trimurti emos eurus $ECF_JOB$ $ECF_JOBOUT$"
     cmd = "/usr/local/apps/python/2.7.12-01/bin/python $ECF_JOB$"
     WDIR = pwd
     ODIR = pwd
 
-    load = (Label("info", "mirror suites..."),
-            Variables(ECF_MICRO=MICRO[0],
-                      ECF_HOME=ODIR,
-                      ECF_EXTN=".py",
-                      ECF_JOB_CMD=cmd, ))
+    load = (
+        Label("info", "mirror suites..."),
+        Variables(
+            ECF_MICRO=MICRO[0],
+            ECF_HOME=ODIR,
+            ECF_EXTN=".py",
+            ECF_JOB_CMD=cmd,
+        ),
+    )
     if load_only:
         return load
-    return Task(name).add(
-        Cron("04:00 20:00 " + rec),
-        If(var, load))
+    return Task(name).add(Cron("04:00 20:00 " + rec), If(var, load))
 
 
 ############################
@@ -171,14 +183,17 @@ def timer(a, b):
         return
     child.report("timeout")
     child.report("complete")
+
+
 import signal
+
 signal.signal(signal.SIGALRM, timer)
 signal.alarm(180)
 
 
 ############################
 class Child(object):
-    """ facilitate job behaviour with ecFlow server:
+    """facilitate job behaviour with ecFlow server:
     just instanciate and call complete when finished
 
     obj = Child(); obs.report("complete")
@@ -188,32 +203,37 @@ class Child(object):
 
     def __init__(self):
         import signal
-        env = {"ECF_HOST": "$ECF_HOST:$",
-               # check can be on a server, child on another
-               "ECF_PASS": "$ECF_PASS$",
-               "ECF_NAME": "$ECF_NAME$",
-               "ECF_PORT": "$ECF_PORT:0$",
-               "ECF_TRYNO": "$ECF_TRYNO$", }
+
+        env = {
+            "ECF_HOST": "$ECF_HOST:$",
+            # check can be on a server, child on another
+            "ECF_PASS": "$ECF_PASS$",
+            "ECF_NAME": "$ECF_NAME$",
+            "ECF_PORT": "$ECF_PORT:0$",
+            "ECF_TRYNO": "$ECF_TRYNO$",
+        }
         self.client = None
         if MICRO[0] in env["ECF_PORT"]:
             print("#MSG: cli mode")
             return
         print("#MSG: will communicate with server...")
         print("#MSG: kill: ssh %s kill -15 %d" % (os.uname()[1], os.getpid()))
-        for sig in (signal.SIGINT,
-                    signal.SIGHUP,
-                    signal.SIGQUIT,
-                    signal.SIGILL,
-                    signal.SIGTRAP,
-                    signal.SIGIOT,
-                    signal.SIGBUS,
-                    signal.SIGFPE,
-                    signal.SIGUSR1,
-                    signal.SIGUSR2,
-                    signal.SIGPIPE,
-                    signal.SIGTERM,
-                    signal.SIGXCPU,
-                    signal.SIGPWR):
+        for sig in (
+            signal.SIGINT,
+            signal.SIGHUP,
+            signal.SIGQUIT,
+            signal.SIGILL,
+            signal.SIGTRAP,
+            signal.SIGIOT,
+            signal.SIGBUS,
+            signal.SIGFPE,
+            signal.SIGUSR1,
+            signal.SIGUSR2,
+            signal.SIGPIPE,
+            signal.SIGTERM,
+            signal.SIGXCPU,
+            signal.SIGPWR,
+        ):
             signal.signal(sig, self.signal_handler)
         self.set_client()
 
@@ -237,15 +257,13 @@ class Child(object):
             self.client.set_child_try_no(int("$ECF_TRYNO$"))
         self.client.child_init()
 
-        self.client.child_label("info", "%s" % strftime("%Y-%m-%d %H:%M:%S",
-                                                        gmtime()))
+        self.client.child_label("info", "%s" % strftime("%Y-%m-%d %H:%M:%S", gmtime()))
         self.client.set_child_timeout(20)
         print(self.client)
 
-
     def signal_handler(self, signum, frame):
         """ catch signal """
-        print('Aborting: Signal handler called with signal ', signum)
+        print("Aborting: Signal handler called with signal ", signum)
         self.report("abort", "Signal handler called with signal " + str(signum))
 
     def __exit__(self, exc_type, exc_value, traceback):
@@ -270,7 +288,7 @@ class Child(object):
             sys.stderr.flush()
             print("#MSG: stop")
             sys.exit(0)
-        elif msg in ("abort", ):
+        elif msg in ("abort",):
             self.client.child_abort()
             self.client = None
             raise Exception(msg)
@@ -282,21 +300,31 @@ class Child(object):
 
 ############################
 destinations = {
-    "test": "${DEST_HOST:=ecgate}@${DEST_PORT=31415}",
+    "emos": "${DEST_HOST:=localhost}@${DEST_PORT=5001}",
+    "test": "${DEST_HOST:=localhost}@${DEST_PORT=5001}",
+    "mc": "localhost@5003",
 }
 
+
 def gen_suite(host=None, port=None, path=None):
     import ecf
-    from ecf import (Task, Label, Variables, Suite, Defs,
-                     Family, Trigger, Defstatus, Meter, Event)
-    destinations = dict()
+    from ecf import (
+        Task,
+        Label,
+        Variables,
+        Suite,
+        Defs,
+        Family,
+        Trigger,
+        Defstatus,
+        Meter,
+        Event,
+    )
+
+    # destinations = dict()
     defs = Defs()
     sname = "mirror"
-    if DEBUG:
-        print(definitions.keys())
-
-    print(definitions.keys())
-    print(destinations.keys())
+    print(list(definitions.keys()), list(destinations.keys()))
     defs.add_suite(
         Suite(sname).add(
             ecf.Defstatus("suspended"),
@@ -304,29 +332,40 @@ def gen_suite(host=None, port=None, path=None):
             Inlimit("one"),
             gen_task(load_only=True),
             Variables(ALL_ECF=" "),
-            [Family(name).add(
-                Variables(DESTINATIONS=destinations[name]),
-                Label("info", ""),
-                gen_task(0, kind=name), )
-             for name in definitions.keys()
-             # if name in destinations.keys()
-             ]))
+            [
+                Family(name).add(
+                    Variables(DESTINATIONS=destinations[name]),
+                    Label("info", ""),
+                    gen_task(0, kind=name),
+                )
+                for name in list(definitions.keys())
+                # if name in destinations.keys()
+            ],
+        )
+    )
     if DEBUG:
         print(defs)
     return defs
 
 
-
 definitions = {  # strings as path for all nodes below sync
     # or suites, subset of the original, leaves are task...
     # or else not sync'ed
     # shall we add list of string/path ???
-
+    "emos": Suite("emos").add(
+        Defstatus("suspended"), Family("f1").add(Edit(YMD=20320101), Task("t1"))
+    ),
     "test": Suite("test").add(
-        Defstatus("suspended"),
-        Family("f1").add(
-            Edit(YMD=20320101),
-            Task("t1"))), 
+        Defstatus("suspended"), Family("f1").add(Edit(YMD=20320101), Task("t1"))
+    ),
+    "mc": Suite("mc").add(
+        Defstatus("suspended"), Family("main").add(
+            Edit(YMD=20990101), 
+            Family("06bc").add(
+                Task("sweeper"), 
+                Family("fc0006d").add(Task("fc")),
+            ),
+    ), ),
 }
 
 ############################
@@ -334,19 +373,18 @@ definitions = {  # strings as path for all nodes below sync
 
 class Mirror(object):
 
-    """
-$nopp
-$end
-    """
+    """    """
 
     def _protect_oper(self, server):
         if server == "xyz@123":
             if 1:
                 child.report("abort", "protect")
-            elif ("/o" in self.path or
-                  self.path == "all" or
-                  "/eda" in self.path or
-                  "/mc" in self.path):
+            elif (
+                "/o" in self.path
+                or self.path == "all"
+                or "/eda" in self.path
+                or "/mc" in self.path
+            ):
                 raise Exception("# wont do that...")
 
     def _warmup(self):
@@ -356,9 +394,9 @@ $end
             self.source.sync_local()
 
     def _send(self, msg="", client=None, send=False):
-        """ self.grouped is None: no buffering, immediate send
-            msg accumulate (send False by default)
-            msg is sent ("", client, send=True)
+        """self.grouped is None: no buffering, immediate send
+        msg accumulate (send False by default)
+        msg is sent ("", client, send=True)
         """
         if self.grouped is None:
             print("#MSG: send", self.grouped)
@@ -377,8 +415,8 @@ $end
     def __init__(self, server="eurus@1630", path="/e_45r1", replay=False, is_sms=False):
         self.is_sms = is_sms
         self.replay = replay  # allow replay from skel definition
-        self.act = 1         # active ie force change allowed
-        self.snap = 1        # sleep interval
+        self.act = 1  # active ie force change allowed
+        self.snap = 1  # sleep interval
         self.wait = 0  # refresh interval,continue as long as sub/act node exist
         self.path = path
         self.grouped = None  # would use atomic alter
@@ -391,15 +429,15 @@ $end
             self.servers = server.split(" ")
         elif "@" in server:
             host, port = server.split("@")
-            self.servers = ("%s@%s" % (host, port), )
+            self.servers = ("%s@%s" % (host, port),)
         elif ":" in server:
             host, port = server.split(":")
-            self.servers = ("%s:%s" % (host, port), )
+            self.servers = ("%s:%s" % (host, port),)
         if self.servers[-1] == "":
             del self.servers[-1]
-        host = os.getenv("ECF_HOST", "$ECF_HOST:none$")
+        host = os.getenv("ECF_HOST", "localhost")
         # if MICRO[0] in host: host = "localhost"
-        port = os.getenv("ECF_PORT", "$ECF_PORT$")
+        port = os.getenv("ECF_PORT", "3141")
         if MICRO[0] in port:
             port = 1500 + int(get_uid())
         # when started with ecflow_start.sh
@@ -424,12 +462,14 @@ $end
                 pass
 
     def _set_register(self, path):
-        if '/' == path[0]:
-            suite = str(path.split('/')[1])
-            self.register = [suite, ]
+        if "/" == path[0]:
+            suite = str(path.split("/")[1])
+            self.register = [
+                suite,
+            ]
 
         elif path == "all":
-            self.register = skel.keys()
+            self.register = list(skel.keys())
 
         else:
             child.report("abort", "register")
@@ -442,7 +482,11 @@ $end
             top = client.get_defs().find_abs_node("/" + suite)
 
             if top is None:
-                print("#WAR: node not found", suite, server, )
+                print(
+                    "#WAR: node not found",
+                    suite,
+                    server,
+                )
                 if stop:
                     child.report("abort", "check")
                 elif self.act and server != self.sname:
@@ -457,7 +501,7 @@ $end
                         defs.add_suite(definitions[suite])
                         host = "localhost"
                         client.load(defs)
-                        client.suspend('/' + suite)
+                        client.suspend("/" + suite)
                         client.begin_suite(suite)
                         client.sync_local()
                     else:
@@ -466,8 +510,9 @@ $end
                     pass
 
             elif server != self.sname and not (
-                    top.is_suspended() or  # normal backup server
-                    "%s" % top.get_state() == "unknown"):  # test server
+                top.is_suspended()
+                or "%s" % top.get_state() == "unknown"  # normal backup server
+            ):  # test server
                 print("#ERR: top node shall be suspended - NOGO")
                 print("#ERR:", server, top.name(), top.get_state())
                 if 1:
@@ -478,8 +523,8 @@ $end
             else:
                 pass
 
-            if suite not in definitions.keys():
-                raise Exception(definitions.keys(), suite)
+            if suite not in list(definitions.keys()):
+                raise Exception(list(definitions.keys()), suite)
 
             if type(definitions[suite]) == str:
                 path = definitions[suite]
@@ -511,8 +556,8 @@ $end
                     break
 
         for vdest in ndest.variables:
-                if vdest.name() == name:
-                    break
+            if vdest.name() == name:
+                break
         pnode = ndest.get_abs_node_path()
         pnode = nfrom.get_abs_node_path()
 
@@ -532,25 +577,37 @@ $end
 
         if vfrom.name() == vname and str(vfrom.value()) != str(vval) or FORCE:
             if type(vfrom) == Repeat:
-                self.action(ndest.get_abs_node_path(), server, client,
-                            kind="repeat", value=str(vfrom.value()),
-                            msg="repeat requeue")
+                self.action(
+                    ndest.get_abs_node_path(),
+                    server,
+                    client,
+                    kind="repeat",
+                    value=str(vfrom.value()),
+                    msg="repeat requeue",
+                )
             else:
-                self.action(pnode, server, client, kind=name,
-                            value=str(vfrom.value()), msg="value update")
+                self.action(
+                    pnode,
+                    server,
+                    client,
+                    kind=name,
+                    value=str(vfrom.value()),
+                    msg="value update",
+                )
 
     def process(self, server=None, client=None, item=None, var=False):
         if server is None:
             self._check(self.sname, self.source, 1)
 
             for server in self.servers:
-                server = server.replace('@', ':')
+                server = server.replace("@", ":")
                 if DEBUG:
                     print("#DBG: target is", server)
-                host, port = server.split(':')
+                host, port = server.split(":")
 
                 if int(port) < 65536 and 0 == comm(
-                        ECFLOWC + "--ping --port %s --host %s" % (port, host), False):
+                    ECFLOWC + "--ping --port %s --host %s" % (port, host), False
+                ):
                     client = ecflow.Client(server)
                     client.ch_register(False, self.register)
                     client.sync_local()
@@ -581,14 +638,15 @@ $end
             return
 
         elif server == self.sname:
-            child.report("abort", "same name")  # DONT
+            child.report("abort", "same name " + server + " " + self.sname)  # DONT
 
         elif client is None:
             child.report("abort", "no client")  # DONT
 
         elif type(item) in (ecflow.Suite, ecf.Suite):
 
-            if 0: pass
+            if 0:
+                pass
             else:
                 # suite =
                 # client.get_defs().find_abs_node(item.get_abs_node_path())
@@ -596,8 +654,7 @@ $end
                 # print(type(client), item.fullname(), type(suite))
                 if suite:
                     if not suite.is_suspended():
-                        print("#ERR: top node shall be suspended - stop",
-                              suite, server)
+                        print("#ERR: top node shall be suspended - stop", suite, server)
                         return
                     for node in suite.nodes:
                         self.process(server, client, node, var)
@@ -606,15 +663,19 @@ $end
         elif type(item) in (ecflow.Family, ecflow.Task):
             pnode = item.get_abs_node_path()
             nfrom = self.source.get_defs().find_abs_node(pnode)
-            if 0: pass
+            if 0:
+                pass
             else:
                 ndest = client.get_defs().find_abs_node(pnode)
 
             if nfrom is None:
                 if var:
                     return  # ignore
-                print("#ERR: node not found, please update mirror.py skel",
-                      pnode, self.sname)
+                print(
+                    "#ERR: node not found, please update mirror.py skel",
+                    pnode,
+                    self.sname,
+                )
                 child.report("abort", "nfrom")
 
             elif ndest is None:
@@ -630,7 +691,8 @@ $end
             else:
                 raise Exception(pnode, self.source, "nfrom is not")
 
-            if 0: pass
+            if 0:
+                pass
             else:
                 dstate = "%s" % ndest.get_state()
             is_task = type(item) == ecf.Task
@@ -642,17 +704,27 @@ $end
                         continue
                     if evd.value() == evs.value():
                         break
-                    print("#event", evs.name(), evd.number(), evs.number(),
-                          evd.value(), evs.value())
+                    print(
+                        "#event",
+                        evs.name(),
+                        evd.number(),
+                        evs.number(),
+                        evd.value(),
+                        evs.value(),
+                    )
                     if evs.value():
                         if evs.name() == "":
-                            self._send("alter change event %d set %s;" %
-                                       (evs.number(), pnode), client)
+                            self._send(
+                                "alter change event %d set %s;" % (evs.number(), pnode),
+                                client,
+                            )
                             # client.alter(pnode, "change", "event", "%d" %
                             # evs.number(), "set")
                         else:
-                            self._send("alter change event %s set %s;" %
-                                       (evs.name(), pnode), client)
+                            self._send(
+                                "alter change event %s set %s;" % (evs.name(), pnode),
+                                client,
+                            )
                         # else: client.alter(pnode, "change", "event",
                         # evs.name(), "set")
 
@@ -668,27 +740,42 @@ $end
                         if value > 100:
                             value = 100
                         if value > 0:
-                            self._send("alter change meter %s %s %s;" % (
-                                evs.name(), value, pnode), client)
+                            self._send(
+                                "alter change meter %s %s %s;"
+                                % (evs.name(), value, pnode),
+                                client,
+                            )
                         # client.alter(pnode, "change", "meter", evs.name(),
                         # "%s" % evs.value())
                     except:
                         pass
 
             if status != dstate or FORCE:
-                print("#WAR: diff ", pnode, status, dstate, )
+                print(
+                    "#WAR: diff ",
+                    pnode,
+                    status,
+                    dstate,
+                )
                 if status == "complete":
-                    self.action(pnode, server, client, status, is_task,
-                                msg="forced complete")
+                    self.action(
+                        pnode, server, client, status, is_task, msg="forced complete"
+                    )
                     if not is_task:
                         self._send("", client, send=True)
                         return
 
                 elif status == "queued":
                     # self._send("force queued %s;" % (pnode), client)
-                    self.action(pnode, server, client, status, is_task,
-                                msg="forced queued")
-                elif status in ("submitted", "active", "unknown", "aborted", ):
+                    self.action(
+                        pnode, server, client, status, is_task, msg="forced queued"
+                    )
+                elif status in (
+                    "submitted",
+                    "active",
+                    "unknown",
+                    "aborted",
+                ):
                     print("#IGN: status is active/submit, ignored")
                 else:
                     raise Exception(status)
@@ -705,16 +792,19 @@ $end
         else:
             raise Exception(type(item), item)
 
-    def action(self, pnode, server, client, kind, is_task=False,
-               value="20010101",
-               msg=""):
+    def action(
+        self, pnode, server, client, kind, is_task=False, value="20010101", msg=""
+    ):
         if not self.act:
             return
 
         self._protect_oper(server)
 
         print("#MSG:", msg)
-        if kind in ("active", "submitted", ):
+        if kind in (
+            "active",
+            "submitted",
+        ):
             return
         elif FORCE:
             pass  # SMS ONLY
@@ -735,17 +825,31 @@ $end
         else:  # var
             if DEBUG:
                 print("#DBG: update var", kind, value)
-            if kind in ("queued", ):
+            if kind in ("queued",):
                 pass
-            elif kind not in ("YMD", "JUL", "DAY", "SCHOST", "STHOST", 
-                              "YYYY", "MM", "ECF_FILES",
-                              "INIBEGINDATE", "MIXTASK"):
+            elif kind not in (
+                "YMD",
+                "JUL",
+                "DAY",
+                "SCHOST",
+                "STHOST",
+                "YYYY",
+                "MM",
+                "ECF_FILES",
+                "INIBEGINDATE",
+                "MIXTASK",
+            ):
                 raise Exception(kind)
-            if 0: pass
+            if 0:
+                pass
             else:
                 client.requeue(pnode)
-                self._send("alter change variable %s %s %s;" %
-                           (kind, value, pnode), client, True)
+                self._send(
+                    "alter change variable %s %s %s;" % (kind, value, pnode),
+                    client,
+                    True,
+                )
+
 
 # ignore Family + queued while is might just be that we dont mirror all
 # fam/tasks and inheritance get it already complete in dest while still
@@ -755,6 +859,7 @@ $end
 ############################
 def replay(path, defs=None):
     import ecf
+
     miss = "@undef@"
     host = os.getenv("ECF_HOST", miss)
     if host == miss:
@@ -767,7 +872,12 @@ def replay(path, defs=None):
     if DEBUG:
         print(defs)
     # print(defs)
-    if "localhost" in host and port in ("3141", 3141) and ("/test" in path) and "/mirror" not in path:
+    if (
+        "localhost" in host
+        and port in ("3141", 3141)
+        and ("/test" in path)
+        and "/mirror" not in path
+    ):
         raise Exception("dont")
 
     print("#MSG: replacing %s in " % path, host, port, defs)
@@ -776,10 +886,11 @@ def replay(path, defs=None):
 
 
 def comm(cmd, rem=True):
-    import commands
-    if rem and cmd in memo.keys():
+    import subprocess
+
+    if rem and cmd in list(memo.keys()):
         return memo[cmd]
-    (rc, res) = commands.getstatusoutput(cmd)
+    (rc, res) = subprocess.getstatusoutput(cmd)
     print("#COMM:", rc, res, cmd)
     if rem:
         memo[cmd] = rc
@@ -792,19 +903,19 @@ class TestMirror(unittest.TestCase):
 
     def test_1(self, test_ok=1):
         sname = "mirror"
-        replay('/' + sname, gen_suite())
+        replay("/" + sname, gen_suite())
 
 
 memo = dict()
 ############################
-if __name__ == '__main__':
+if __name__ == "__main__":
     import argparse
+
     parser = argparse.ArgumentParser(add_help=False)
     parser.add_argument("-?", default=0, help="help")
     parser.add_argument("-f", "--force", action="store_true", help="force")
     parser.add_argument("-h", default=0, help="help")
-    parser.add_argument(
-        "-m", "--mirror", default="localhost@31415", help="mirror")
+    parser.add_argument("-m", "--mirror", default="localhost@31415", help="mirror")
     parser.add_argument("-p", "--path", default="/mirror/test", help="path")
     parser.add_argument("-r", "--replay", action="store_true", help="replay")
     parser.add_argument("-t", "--test", action="store_true", help="test")
@@ -813,15 +924,15 @@ if __name__ == '__main__':
     parsed = parser.parse_args()
     global FORCE
     FORCE = parsed.force
-    print(parsed.path, parsed.mirror, parsed.replay,
-          parsed.sms, parsed.force, parsed.test)
+    print(parsed.path, parsed.mirror, parsed.replay, parsed.force, parsed.test)
     # raise Exception
     child = Child()
 
     if parsed.usage:
-        print("""
+        print(
+            """
 
-* mirror (slow real-time) a source suite from a source server to a destination server
+* mirrors (slow real-time) a source suite, from a source server, to a destination server
 * mirror suite can be hosted on the source, on the destination or another server
 * this script was used in ecflow course to demonstrate
   * one script that can be used from the command line
@@ -838,15 +949,46 @@ if __name__ == '__main__':
 * update mirror.py: replay add "if" for "protection" not to overwrite source suite by mistake
 
 * download a copy from the source suite
-  ecflow_client --port ${ECF_PORT:3141} --host ${ECF_HOST:localhost} --get > tmp.def
+  ecflow_client --port 3141 --host localhost --get > tmp.def
 
 * load the mirror suite on the source server
-  SUITE=/test ECF_HOST=${ECF_HOST:=localhoast} ECF_PORT=${ECF_PORT:=3141} ./mirror.py -p /mirror/$SUITE -r # load
+  SUITE=test ECF_HOST=localhost ECF_PORT=3141 ./mirror.py -p /mirror/test -r # load
 
 * play (suspended) mirrored suite in destination
-  ECF_HOST=${DEST_HOST:=ecgate} ECF_PORT=${DEST_PORT:=31415} ./mirror.py -m $DEST_HOST@$DEST_PORT -p /$SUITE
+  ECF_HOST=ecgate ECF_PORT=31415 ./mirror.py -m ecgate:31415 -p /test
 
-""")
+module load python3; module load ecflow/5.7.0
+ecflow_start.sh -p 5001 # source
+ecflow_start.sh -p 5003 # destination
+# ecflow_client --host vecf1 --port 44444 --get mc > mc.dump # an example suite
+ecflow_client --host localhost --port 5001 --replace /mc mc.dump # we take it as a source
+# definitions =  # contains "mc" definition
+# destinations = { # contains one destination for mc at least
+ export  SUITE=mc ECF_HOST=localhost ECF_PORT=5001
+ ./mirror.py -p /mirror/mc -r # load mirror on source server # might be destination or another server yet
+# ImportError: No module named ecf # ecf shall be in the path, at least it can found in ecflow distrib as 
+# ecflow/Pyext/samples/api/ecf.py
+# ('#MSG: replacing /mirror/test in ', 'localhost', '5001', #5.7.0 # loading OK
+# begin mirror - 
+# Script OK? mirror.py undef ECF_FILES directory?
+# Edit OK? $ is used as ECF_MICRO
+# cron OK?
+# set DESTINATIONS variable as expected
+
+ECF_HOST=localhost ECF_PORT=5003 python3 ./mirror.py -m localhost:5003 -p /mc # ok
+#COMM: 0 ping server(localhost:5003) succeeded in 00:00:00.001058  ~1 milliseconds ecflow_client --ping --port 5003 --host localhost # OK
+# replay?
+ECF_PORT=5003 python3 ./mirror.py -m localhost:5003 -p /mc -r # ok mc loaded on target
+# begin /mc in 5003 (it looks suspended
+# edit ECF_JOB_CMD "python3 $ECF_JOB$ > $ECF_JOBOUT$ &"
+
+# python3 /home/ma/map/mirror/mc/mirror.job1 # OK after ECF_PASS FREE running as zombie ommand line
+# ImportError: No module named 'ecf' # jobs lost in submit
+
+# mirror jobs submits and complete OKWITH ECF_JOB_CMD updated as 
+module load python3 && module load ecflow/5.7.0 && cd /home/ma/map && python3 $ECF_JOB$ > $ECF_JOBOUT$ 2>&1 &
+"""
+        )
         sys.exit(2)
 
     if not MICRO[0] in "$ECF_PORT$":
@@ -858,10 +1000,10 @@ if __name__ == '__main__':
         sys.argv.pop()
         unittest.main()
 
-`    elif parsed.path and parsed.replay:
+    elif parsed.path and parsed.replay:
         print("#MSG: path and replay", parsed.path, parsed.replay)
         port = int(os.getenv("SMS_PROG", 0))
-        s = parsed.path.split('/')[1]
+        s = parsed.path.split("/")[1]
         defs = None
         if "mirror" not in parsed.path:
             defs = Defs()
@@ -870,7 +1012,7 @@ if __name__ == '__main__':
 
     elif parsed.mirror and parsed.path:
         print(parsed.mirror, "#", parsed.path, parsed.replay, type(Mirror))
-        mirror = Mirror(parsed.mirror, parsed.path, parsed.replay, parsed.sms)
+        mirror = Mirror(parsed.mirror, parsed.path, parsed.replay)
         print("#MSG: step")
         mirror.process()
         print("#MSG: step")
@@ -882,13 +1024,11 @@ if __name__ == '__main__':
     print("#MSG: step")
     child.report("complete")
 """
-$nopp
-  export ECF_HOST=localhost ECF_PORT=$((1500 + $(id -u))) SUITE=/test
-  ecflow_client --port $ECF_PORT --host $ECF_HOST --get > tmp.def
-  ./mirror.py -p /mirror/$SUITE -r # load
+  export ECF_HOST=localhost ECF_PORT=5001 SUITE=mc
+  ecflow_client --get /mc > tmp.def
+  ./mirror.py -p /mirror/mc -r # load
 
-  ECF_HOST=${DEST_HOST:=localhost} ECF_PORT=${DEST_PORT:=31415} ./mirror.py -m $DEST_HOST@$DEST_PORT -p /$SUITE
+  ECF_HOST=localhost ECF_PORT=31415 ./mirror.py -m localhost:31415 -p /mc
 
 /tmp/map/work/git/ecflow/Pyext/samples/mirror.py
-$end
 """
