@@ -18,7 +18,8 @@
 const char* DefsDoc::add()
 {
    return  "add(..) provides a way to append Nodes and attributes\n\n"
-           "This is best illustrated with an example::\n\n"
+           "This is best illustrated with an example:\n\n"
+           ".. code-block:: python\n\n"
            " defs = Defs().add(\n"
            "     Suite('s1').add(\n"
            "         Clock(1, 1, 2010, False),\n"
@@ -43,12 +44,13 @@ const char* DefsDoc::add()
            "             Autocancel(3)\n"
            "             ),\n"
            "         [ Family('f{}'.format(i)) for i in range(1,6)]))\n\n"
-           "We can also use '+=' with a list here are a few examples::\n\n"
+           "We can also use '+=' with a list here are a few examples:\n\n"
+           ".. code-block:: python\n\n"
            " defs = Defs();\n"
            " defs += [ Suite('s2'),Edit({ 'x1':'y', 'aa1':'bb'}, a='v',b='b') ]\n\n"
-           "::\n\n"
+           ".. code-block:: python\n\n"
            " defs += [ Suite('s{}'.format(i)) for i in range(1,6) ]\n\n"
-           "::\n\n"
+           ".. code-block:: python\n\n"
            " defs = Defs()\n"
            " defs += [ Suite('suite').add(\n"
            "              Task('x'),\n"
@@ -59,7 +61,7 @@ const char* DefsDoc::add()
            "              [ Task('t{}'.format(i)) for i in range(1,6) ],\n"
            "              )]\n\n"
            "It is also possible to use '+'\n\n"
-           "::\n\n"
+           ".. code-block:: python\n\n"
            " defs = Defs() + Suite('s1')\n"
            " defs.s1 += Autocancel(1, 10, True)\n"
            " defs.s1 += Task('t1') + Edit({ 'e':1, 'f':'bb'}) +\\ \n"
@@ -81,7 +83,7 @@ const char* DefsDoc::part_expression_doc()
 {
    return
             "PartExpression holds part of a `trigger`_ or `complete expression`_.\n\n"
-            "Expressions can contain references to `event`_, `meter`_ s, user variables,\n"
+            "Expressions can contain references to `event`_\\s, `meter`_\\ s, user variables,\n"
             "`repeat`_ variables and generated variables. The part expression allows us\n"
             "to split a large trigger or complete expression into smaller ones\n"
             "\nConstructor::\n\n"
@@ -92,11 +94,13 @@ const char* DefsDoc::part_expression_doc()
             "      bool and_exp: If true the expression is to be anded, with a previously added expression\n"
             "                    If false the expression is to be 'ored', with a previously added expression\n"
             "\nUsage:\n"
-            "To add simple expression this class can be by-passed, i.e. can use::\n\n"
+            "To add simple expression this class can be by-passed, i.e. can use:\n\n"
+            ".. code-block:: python\n\n"
             "  task = Task('t1')\n"
             "  task.add_trigger( 't2 == active' )\n"
             "  task.add_complete( 't2 == complete' )\n\n"
-            "To add large triggers and complete expression::\n\n"
+            "To add large triggers and complete expression:\n\n"
+            ".. code-block:: python\n\n"
             "  exp1 = PartExpression('t1 == complete')\n  # a simple expression can be added as a string\n"
             "  ....\n"
             "  task2.add_part_trigger( PartExpression('t1 == complete or t4 == complete') ) \n"
@@ -121,7 +125,8 @@ const char* DefsDoc::expression_doc()
             "   Expression( part )\n"
             "      PartExpression part: The first part expression should have no 'and/or' set\n"
             "\nUsage:\n"
-            "To add simple expression this class can be by passed, i.e. can use::\n\n"
+            "To add simple expression this class can be by passed, i.e. can use:\n\n"
+            ".. code-block:: python\n\n"
             "  task = Task('t1')\n"
             "  task.add_trigger( 't2 == active' )\n"
             "  task.add_complete( 't2 == complete' )\n"
@@ -129,14 +134,15 @@ const char* DefsDoc::expression_doc()
             "  task = Task('t2')\n"
             "  task.add_trigger( 't1 == active' )\n"
             "  task.add_part_trigger( 't3 == active', True)\n\n"
-            "To store and add large expressions use a Expression with PartExpression::\n\n"
+            "To store and add large expressions use a Expression with PartExpression:\n\n"
+            ".. code-block:: python\n\n"
             "  big_expr = Expression( PartExpression('t1 == complete or t4 == complete') )\n"
             "  big_expr.add( PartExpression('t5 == active',True) )\n"
             "  big_expr.add( PartExpression('t7 == active',False) )\n"
             "  task.add_trigger( big_expr)\n\n"
             "In the example above the trigger for task is equivalent to\n"
             "'t1 == complete or t4 == complete and t5 == active or t7 == active'\n\n"
-            "::\n\n"
+            ".. code-block:: python\n\n"
             "  big_expr2 = Expression('t0 == complete'))\n"
             "  big_expr2.add( PartExpression('t1 == complete or t4 == complete',True) )\n"
             "  big_expr2.add( PartExpression('t5 == active',False) )\n"
@@ -160,12 +166,14 @@ const char* DefsDoc::add_trigger_doc()
             "  Like wise second and subsequent expression must have 'AND' or 'OR' booleans set\n"
             "\nUsage:\n\n"
             "Note we cannot make multiple add_trigger(..) calls on the same `task`_!\n"
-            "to add a simple trigger::\n\n"
+            "to add a simple trigger:\n\n"
+            ".. code-block:: python\n\n"
             "  task1.add_trigger( 't2 == active' )\n"
             "  task2.add_trigger( 't1 == complete or t4 == complete' )\n"
             "  task3.add_trigger( 't5 == active' )\n"
             "\n"
-            "Long expression can be broken up using add_part_trigger::\n\n"
+            "Long expression can be broken up using add_part_trigger:\n\n"
+            ".. code-block:: python\n\n"
             "  task2.add_part_trigger( 't1 == complete or t4 == complete')\n"
             "  task2.add_part_trigger( 't5 == active',True)  # True means  AND\n"
             "  task2.add_part_trigger( 't7 == active',False) # False means OR\n\n"
@@ -188,22 +196,28 @@ const char* DefsDoc::trigger()
             "  Like wise second and subsequent expression must have 'AND' or 'OR' booleans set\n"
             "\nUsage:\n\n"
             "Multiple trigger will automatically be *anded* together, If *or* is required please\n"
-            "use bool 'False' as the last argument i.e ::\n\n"
+            "use bool 'False' as the last argument i.e. :\n\n"
+            ".. code-block:: python\n\n"
             "  task1.add( Trigger('t2 == active' ),\n"
             "             Trigger('t1 == complete or t4 == complete' ),\n"
             "             Trigger('t5 == active',False))\n"
             "\n"
-            "The trigger for task1 is equivalent to ::\n\n"
+            "The trigger for task1 is equivalent to :\n\n"
+            ".. code-block:: python\n\n"
             "  t2 == active and t1 == complete or t4 == complete or t5 == active\n\n"
             "Since a large number of triggers are of the form `<node> == complete` there are\n"
-            "are short cuts, these involves a use of a list ::\n\n"
+            "are short cuts, these involves a use of a list :\n\n"
+            ".. code-block:: python\n\n"
             "  task1.add( Trigger( ['t2','t3'] )) #  This is same as t2 == complete and t3 == complete\n\n"
-            "You can also use a node ::\n\n"
+            "You can also use a node :\n\n"
+            ".. code-block:: python\n\n"
             "  task1.add( Trigger( ['t2',taskx] ))\n\n"
             "If the node 'taskx' has a parent, we use the full hierarchy, hence we will get a trigger\n"
-            "of the form ::\n\n"
+            "of the form :\n\n"
+            ".. code-block:: python\n\n"
             "  t2 ==complete and /suite/family/taskx == complete\n\n"
-            "If however node taskx has not yet been added to its parent, we use a relative name in the trigger ::\n\n"
+            "If however node taskx has not yet been added to its parent, we use a relative name in the trigger :\n\n"
+            ".. code-block:: python\n\n"
             "  t2 ==complete and taskx == complete\n"
             ;
 }
@@ -222,7 +236,8 @@ const char* DefsDoc::add_variable_doc()
             "the last value added is kept.\n"
             "\nException:\n\n"
             "- Writes warning to standard output, if a duplicate variable name is added\n"
-            "\nUsage::\n\n"
+            "\nUsage:\n\n"
+            ".. code-block:: python\n\n"
             "  task.add_variable( Variable('ECF_HOME','/tmp/'))\n"
             "  task.add_variable( 'TMPDIR','/tmp/')\n"
             "  task.add_variable( 'COUNT',2)\n"
@@ -238,10 +253,12 @@ const char* DefsDoc::add_label_doc()
             "Labels can be updated from the jobs files, via `child command`_\n"
             "\nException:\n\n"
             "- Throws RuntimeError if a duplicate label name is added\n"
-            "\nUsage::\n\n"
+            "\nUsage:\n\n"
+            ".. code-block:: python\n\n"
             "  task.add_label( Label('TEA','/me/'))\n"
             "  task.add_label( 'Joe','/me/')\n\n"
-            "The corresponding child command in the .ecf script file might be::\n\n"
+            "The corresponding child command in the .ecf script file might be:\n\n"
+            ".. code-block:: shell\n\n"
             "  ecflow_client --label=TEA time\n"
             "  ecflow_client --label=Joe ninety\n"
             ;
@@ -255,7 +272,8 @@ const char* DefsDoc::add_limit_doc()
             "For a node to be in a limit, a `inlimit`_ must be used.\n"
             "\nException:\n\n"
             "- Throws RuntimeError if a duplicate limit name is added\n"
-            "\nUsage::\n\n"
+            "\nUsage:\n\n"
+            ".. code-block:: python\n\n"
             "  family.add_limit( Limit('load',12) )\n"
             "  family.add_limit( 'load',12 )\n"
             ;
@@ -268,7 +286,8 @@ const char* DefsDoc::add_inlimit_doc()
             "InLimit reference a `limit`_/:py:class:`ecflow.Limit`. Duplicate InLimits are not allowed\n"
             "\nException:\n\n"
             "- Throws RuntimeError if a duplicate is added\n"
-            "\nUsage::\n\n"
+            "\nUsage:\n\n"
+            ".. code-block:: python\n\n"
             "  task2.add_inlimit( InLimit('limitName','/s1/f1',2) )\n"
             "  task2.add_inlimit( 'limitName','/s1/f1',2 )\n"
             ;
@@ -289,7 +308,8 @@ const char* DefsDoc::suite_doc()
             "\nException:\n\n"
             "- Throws a RuntimeError if the name is not valid\n"
             "- Throws a RuntimeError if duplicate suite names added\n"
-            "\nUsage::\n\n"
+            "\nUsage:\n\n"
+            ".. code-block:: python\n\n"
             "  defs = Defs()                  # create a empty definition. Root of all Suites\n"
             "  suite = Suite('suite_1')       # create a stand alone suite\n"
             "  defs.add_suite(suite)          # add suite to definition\n"
@@ -305,7 +325,7 @@ const char* DefsDoc::family_doc()
 {
    return
             "Create a `family`_ `node`_.A Family node lives inside a `suite`_ or another `family`_\n\n"
-            "A family is used to collect `task`_ s together or to group other families.\n"
+            "A family is used to collect `task`_\\ s together or to group other families.\n"
             "Typically you place tasks that are related to each other inside the same family\n"
             "analogous to the way you create directories to contain related files.\n"
             "There are two ways of adding a family, see example below.\n"
@@ -318,7 +338,8 @@ const char* DefsDoc::family_doc()
             "\nException:\n\n"
             "- Throws a RuntimeError if the name is not valid\n"
             "- Throws a RuntimeError if a duplicate family is added\n"
-            "\nUsage::\n\n"
+            "\nUsage:\n\n"
+            ".. code-block:: python\n\n"
             "  suite = Suite('suite_1')       # create a suite\n"
             "  family = Family('family_1')    # create a family\n"
             "  suite.add_family(family)       # add created family to a suite\n"
@@ -349,7 +370,8 @@ const char* DefsDoc::task_doc()
             "\nException:\n\n"
             "- Throws a RuntimeError if the name is not valid\n"
             "- Throws a RuntimeError if a duplicate Task is added\n"
-            "\nUsage::\n\n"
+            "\nUsage:\n\n"
+            ".. code-block:: python\n\n"
             "  task = Task('t1')            # create a stand alone task\n"
             "  family.add_task(task)        # add to the family\n"
             "  t2 = family.add_task('t2')   # create a task t2 and add to the family\n\n"
@@ -366,9 +388,9 @@ const char* DefsDoc::task_doc()
 const char* DefsDoc::alias_doc()
 {
    return
-            "A Aliases is create by the GUI or via edit_script command\n\n"
-            "Aliases provide a mechanism to edit/test task scripts without effecting the suite\n"
-            "The Aliases parent is always a Task.Multiple Alias can be added\n"
+            "Aliases can be created by the GUI or via edit_script command.\n\n"
+            "Aliases provide a mechanism to edit/test task scripts without effecting the suite.\n"
+            "The Aliases parent is always a Task. Multiple Alias can be added\n"
             ;
 }
 
@@ -380,7 +402,8 @@ const char* DefsDoc::add_suite_doc()
             "\nException:\n\n"
             "- Throws RuntimeError is the suite name is not valid\n"
             "- Throws RuntimeError if duplicate suite is added\n"
-            "\nUsage::\n\n"
+            "\nUsage:\n\n"
+            ".. code-block:: python\n\n"
             "  defs = Defs()                # create a empty defs\n"
             "  suite = Suite('suite')       # create a stand alone Suite \n"
             "  defs.add_suite(suite)        # add suite to defs\n"
@@ -400,12 +423,14 @@ const char* DefsDoc::add_extern_doc()
 {
    return
             "`extern`_ refer to nodes that have not yet been defined typically due to cross suite `dependencies`_\n\n"
-            "`trigger`_ and `complete expression`_ s may refer to paths, and variables in other suites, that have not been\n"
+            "`trigger`_ and `complete expression`_\\ s may refer to paths, and variables in other suites, that have not been\n"
             "loaded yet. The references to node paths and variable must exist, or exist as externs\n"
             "Externs can be added manually or automatically.\n\n"
-            "Manual Method::\n\n"
+            "Manual Method:\n\n"
+            ".. code-block:: python\n\n"
             "  void add_extern(string nodePath )\n"
-            "\nUsage::\n\n"
+            "\nUsage:\n\n"
+            ".. code-block:: python\n\n"
             "  defs = Defs('file.def')\n"
             "  ....\n"
             "  defs.add_extern('/temp/bill:event_name')\n"
@@ -419,9 +444,10 @@ const char* DefsDoc::add_extern_doc()
             "  that have not been defined. The added benefit of this approach is that duplicates will not\n"
             "  be added. It is the user's responsibility to check that extern's are eventually defined\n"
             "  otherwise trigger expression will not evaluate correctly\n\n"
-            "::\n\n"
+            ".. code-block:: python\n\n"
             "  void auto_add_externs(bool remove_existing_externs_first )\n"
-            "\nUsage::\n\n"
+            "\nUsage:\n\n"
+            ".. code-block:: python\n\n"
             "  defs = Defs('file.def')\n"
             "  ...\n"
             "  defs.auto_add_externs(True)   # remove existing extern first.\n"
@@ -461,7 +487,8 @@ const char* DefsDoc::add_family_doc()
             "for a given parent. Families can be hierarchical.\n"
             "\nException:\n\n"
             "- Throws RuntimeError if a duplicate is added\n"
-            "\nUsage::\n\n"
+            "\nUsage:\n\n"
+            ".. code-block:: python\n\n"
             "  suite = Suite('suite')          # create a suite\n"
             "  f1 = Family('f1')               # create a family\n"
             "  suite.add_family(f1)            # add family to suite\n"
@@ -477,7 +504,8 @@ const char* DefsDoc::add_task_doc()
             "for a given parent. Task can be added to Familiy's or Suites.\n"
             "\nException:\n\n"
             "- Throws RuntimeError if a duplicate is added\n"
-            "\nUsage::\n\n"
+            "\nUsage:\n\n"
+            ".. code-block:: python\n\n"
             "  f1 = Family('f1')      # create a family\n"
             "  t1 = Task('t1')          # create a task\n"
             "  f1.add_task(t1)          # add task to family\n"
@@ -500,9 +528,10 @@ const char* DefsDoc::add_definition_doc()
             "   Defs(Suite | Edit )\n"
             "      :py:class:`ecflow.Suite`- One or more suites\n\n"
             "      :py:class:`ecflow.Edit` - specifies user defined server variables\n"
-            "\nExample::\n\n"
-            "  # Build definition using Constructor approach, This allows indentation, to show the structure\n"
-            "  # This is a made up example to demonstrate suite construction:\n"
+            "\nExample:\n\n"
+            ".. code-block:: python\n\n"
+            " # Build definition using Constructor approach, This allows indentation, to show the structure\n"
+            " # This is a made up example to demonstrate suite construction:\n"
             " defs = Defs(\n"
             "     Edit(SLEEP=10,FRED='bill'),  # user defined server variables\n"
             "     Suite('s1'\n"
@@ -535,7 +564,8 @@ const char* DefsDoc::add_definition_doc()
             "  for i in [ '_1', '_2', '_3' ]: family.add_task( 't' + i )\n"
             "  defs.save_as_defs('filename.def')  # save defs into file\n"
             "\n"
-            "Create a Defs from an existing file on disk. ::\n\n"
+            "Create a Defs from an existing file on disk:\n\n"
+            ".. code-block:: python\n\n"
             "  defs = Defs('filename.def')   #  Will open and parse the file and create the Definition\n"
             "  print(defs)\n"
             ;
@@ -545,10 +575,11 @@ const char* DefsDoc::add_event_doc()
 {
    return
             "Add a `event`_. See :py:class:`ecflow.Event`\n"
-            "Events can be referenced in `trigger`_ and `complete expression`_ s\n\n"
+            "Events can be referenced in `trigger`_ and `complete expression`_\\ s\n\n"
             "\nException:\n\n"
             "- Throws RuntimeError if a duplicate is added\n"
-            "\nUsage::\n\n"
+            "\nUsage:\n\n"
+            ".. code-block:: python\n\n"
             "  t1 = Task('t1',\n"
             "            Event(12),\n"
             "            Event(11,'eventx'))             # Create events on Task creation\n\n"
@@ -556,7 +587,8 @@ const char* DefsDoc::add_event_doc()
             "  t1.add_event( Event(11,'Eventname') )\n"
             "  t1.add_event( 12 )\n"
             "  t1.add_event( 13, 'name')\n\n"
-            "To reference event 'flag' in a trigger::\n\n"
+            "To reference event 'flag' in a trigger:\n\n"
+            ".. code-block:: python\n\n"
             "  t1.add_event('flag')\n"
             "  t2 = Task('t2',\n"
             "            Trigger('t1:flag == set'))"
@@ -567,15 +599,17 @@ const char* DefsDoc::add_meter_doc()
 {
    return
             "Add a `meter`_. See :py:class:`ecflow.Meter`\n"
-            "Meters can be referenced in `trigger`_ and `complete expression`_ s\n\n"
+            "Meters can be referenced in `trigger`_ and `complete expression`_\\ s\n\n"
             "\nException:\n\n"
             "- Throws RuntimeError if a duplicate is added\n"
-            "\nUsage::\n\n"
+            "\nUsage:\n\n"
+            ".. code-block:: python\n\n"
             "  t1 = Task('t1',\n"
             "            Meter('met',0,50))                   # create Meter on Task creation\n"
             "  t1.add_meter( Meter('metername',0,100,50) )  # create Meter using function\n"
             "  t1.add_meter( 'meter',0,200)\n\n"
-            "To reference in a trigger::\n\n"
+            "To reference in a trigger:\n\n"
+            ".. code-block:: python\n\n"
             "  t2 = Task('t2')\n"
             "  t2.add_trigger('t1:meter >= 10')\n"
             ;
@@ -588,7 +622,8 @@ const char* DefsDoc::add_date_doc()
             "A value of zero for day,month,year means every day, every month, every year\n"
             "\nException:\n\n"
             "- Throws RuntimeError if an invalid date is added\n"
-            "\nUsage::\n\n"
+            "\nUsage:\n\n"
+            ".. code-block:: python\n\n"
             "  t1 = Task('t1',\n"
             "            Date('1.*.*'),\n"
             "            Date(1,1,2010)))    # Create Date in place\n\n"
@@ -602,7 +637,8 @@ const char* DefsDoc::add_day_doc()
 {
    return
             "Add a `day`_ time dependency. See :py:class:`ecflow.Day`\n\n"
-            "\nUsage::\n\n"
+            "\nUsage:\n\n"
+            ".. code-block:: python\n\n"
             "  t1 = Task('t1',\n"
             "            Day('sunday'))  # Create Day on Task creation\n\n"
             "  t1.add_day( Day(Days.sunday) )\n"
@@ -615,7 +651,8 @@ const char* DefsDoc::add_today_doc()
 {
    return
             "Add a `today`_ time dependency. See :py:class:`ecflow.Today`\n\n"
-            "\nUsage::\n\n"
+            "\nUsage:\n\n"
+            ".. code-block:: python\n\n"
             "  t1 = Task('t1',\n"
             "            Today('+00:30 20:00 01:00')) # Create Today in Task constructor\n\n"
             "  t1.add_today( '00:30' )\n"
@@ -638,7 +675,8 @@ const char* DefsDoc::add_time_doc()
 {
    return
             "Add a `time`_ dependency. See :py:class:`ecflow.Time`\n\n"
-            "\nUsage::\n\n"
+            "\nUsage:\n\n"
+            ".. code-block:: python\n\n"
             "  t1 = Task('t1', Time('+00:30 20:00 01:00')) # Create Time in Task constructor\n"
             "  t1.add_time( '00:30' )\n"
             "  t1.add_time( '+00:30' )\n"
@@ -660,7 +698,8 @@ const char* DefsDoc::add_cron_doc()
 {
    return
             "Add a `cron`_ time dependency. See :py:class:`ecflow.Cron`\n\n"
-            "\nUsage::\n\n"
+            "\nUsage:\n\n"
+            ".. code-block:: python\n\n"
             "  start = TimeSlot(0,0)\n"
             "  finish = TimeSlot(23,0)\n"
             "  incr = TimeSlot(0,30)\n"
@@ -684,7 +723,8 @@ const char* DefsDoc::add_late_doc()
             "Add a `late`_ attribute. See :py:class:`ecflow.Late`\n\n"
             "\nException:\n\n"
             "- Throws a RuntimeError if more than one late is added\n"
-            "\nUsage::\n\n"
+            "\nUsage:\n\n"
+            ".. code-block:: python\n\n"
             "  late = Late()\n"
             "  late.submitted( 20,10 )     # hour,minute\n"
             "  late.active(    20,10 )     # hour,minute\n"
@@ -708,7 +748,8 @@ const char* DefsDoc::add_autocancel_doc()
             "A node may only have one auto cancel attribute\n"
             "\nException:\n\n"
             "- Throws a RuntimeError if more than one auto cancel is added\n"
-            "\nUsage::\n\n"
+            "\nUsage:\n\n"
+            ".. code-block:: python\n\n"
             "  t1 = Task('t1')\n"
             "  t1.add_autocancel( Autocancel(20,10,False) )  # hour,min, relative\n"
             "  t2 = Task('t2')\n"
@@ -737,7 +778,8 @@ const char* DefsDoc::add_autoarchive_doc()
             "A Node may only have one autoarchive attribute\n"
             "\nException:\n\n"
             "- Throws a RuntimeError if more than one auto archive is added\n"
-            "\nUsage::\n\n"
+            "\nUsage:\n\n"
+            ".. code-block:: python\n\n"
             "  t1 = Task('t1')\n"
             "  t1.add_autoarchive( Autoarchive(20,10,False) )  # hour,min, relative\n"
             "  t2 = Task('t2')\n"
@@ -763,7 +805,8 @@ const char* DefsDoc::add_autorestore_doc()
             " - The file ECF_HOME/<host>.<port>.ECF_NAME.check does not exist\n"
             "\nException:\n\n"
             "- Throws a RuntimeError if more than one autorestore is added\n"
-            "\nUsage::\n\n"
+            "\nUsage:\n\n"
+            ".. code-block:: python\n\n"
             "  t1 = Task('t1')\n"
             "  t1.add_autorestore( ['/s1/f1'] )   \n"
             "  t2 = Task('t2')\n"
@@ -793,7 +836,8 @@ const char* DefsDoc::add_repeat_date_doc()
             "   trigger /suite/family:YMD + 1 > 20190101\n"
             "\nException:\n\n"
             "- Throws a RuntimeError if more than one repeat is added\n"
-            "\nUsage::\n\n"
+            "\nUsage:\n\n"
+            ".. code-block:: python\n\n"
             "  t1 = Task('t1')\n"
             "  t1.add_repeat( RepeatDate('YMD',20100111,20100115) )\n\n"
             "  # we can also create a repeat in Task constructor like any other attribute\n"
@@ -808,11 +852,13 @@ const char* DefsDoc::add_repeat_date_list_doc()
             "Add a RepeatDateList attribute. See :py:class:`ecflow.RepeatDateList`\n\n"
             "A node can only have one repeat\n"
             "Reference to a RepeatDateList in a trigger will use date arithmetic. i.e.\n"
-            "Here (/suite/family:YMD + 1) uses date arithmetic only, the result is still an integer::\n\n"
+            "Here (/suite/family:YMD + 1) uses date arithmetic only, the result is still an integer:\n\n"
+            ".. code-block:: python\n\n"
             "  trigger /suite/family:YMD + 1 > 20190101\n\n"
             "\nException:\n\n"
             "- Throws a RuntimeError if more than one repeat is added\n"
-            "\nUsage::\n\n"
+            "\nUsage:\n\n"
+            ".. code-block:: python\n\n"
             "  t1 = Task('t1')\n"
             "  t1.add_repeat( RepeatDateList('YMD',[20100111,20100115]) )\n\n"
             "  # we can also create a repeat in Task constructor like any other attribute\n"
@@ -829,7 +875,8 @@ const char* DefsDoc::add_repeat_integer_doc()
             "A node can only have one `repeat`_\n"
             "\nException:\n\n"
             "- Throws a RuntimeError if more than one repeat is added\n"
-            "\nUsage::\n\n"
+            "\nUsage:\n\n"
+            ".. code-block:: python\n\n"
             "  t1 = Task('t1')\n"
             "  t1.add_repeat( RepeatInteger('testInteger',0,100,2) )\n\n"
             "  # we can also create a repeat in Task constructor like any other attribute\n"
@@ -845,7 +892,8 @@ const char* DefsDoc::add_repeat_string_doc()
             "A node can only have one `repeat`_\n"
             "\nException:\n\n"
             "- Throws a RuntimeError if more than one repeat is added\n"
-            "\nUsage::\n\n"
+            "\nUsage:\n\n"
+            ".. code-block:: python\n\n"
             "  t1 = Task('t1')\n"
             "  t1.add_repeat( RepeatString('test_string',['a', 'b', 'c' ] ) )\n\n"
             "  # we can also create a repeat in Task constructor like any other attribute\n"
@@ -861,7 +909,8 @@ const char* DefsDoc::add_repeat_enumerated_doc()
             "A node can only have one `repeat`_\n"
             "\nException:\n\n"
             "- Throws a RuntimeError if more than one repeat is added\n"
-            "\nUsage::\n\n"
+            "\nUsage:\n\n"
+            ".. code-block:: python\n\n"
             "  t1 = Task('t1')\n"
             "  t1.add_repeat( RepeatEnumerated('test_string', ['red', 'green', 'blue' ] ) )\n\n"
             "  # we can also create a repeat in Task constructor like any other attribute\n"
@@ -877,7 +926,8 @@ const char* DefsDoc::add_repeat_day_doc()
             "A node can only have one `repeat`_\n"
             "\nException:\n\n"
             "- Throws a RuntimeError if more than one repeat is added\n"
-            "\nUsage::\n\n"
+            "\nUsage:\n\n"
+            ".. code-block:: python\n\n"
             "  t2 = Task('t2',\n"
             "            RepeatDay(1))\n"
             ;
@@ -889,7 +939,8 @@ const char* DefsDoc::add_defstatus_doc()
             "Set the default status( `defstatus`_ ) of node at begin or re queue. See :py:class:`ecflow.Defstatus`\n\n"
             "A `defstatus`_ is useful in preventing suites from running automatically\n"
             "once begun, or in setting Task's complete so they can be run selectively\n"
-            "\nUsage::\n\n"
+            "\nUsage:\n\n"
+            ".. code-block:: python\n\n"
             "  t1 = Task('t1') + Defstatus('complete')\n"
             "  t2 = Task('t2').add_defstatus( DState.suspended )\n\n"
             "  # we can also create a Defstatus in the Task constructor like any other attribute\n"
@@ -904,7 +955,8 @@ const char* DefsDoc::jobgenctrl_doc()
             "The class JobCreationCtrl is used in `job creation` checking\n\n"
             "Constructor::\n\n"
             "   JobCreationCtrl()\n\n"
-            "\nUsage::\n\n"
+            "\nUsage:\n\n"
+            ".. code-block:: python\n\n"
             "   defs = Defs('my.def')                     # specify the definition we want to check, load into memory\n"
             "   job_ctrl = JobCreationCtrl()\n"
             "   job_ctrl.set_node_path('/suite/to_check') # will hierarchically check job creation under this node\n"
@@ -932,12 +984,13 @@ const char* DefsDoc::check_job_creation_doc()
             "- recursive includes\n"
             "- manual and comments `pre-processing`_\n"
             "- `variable substitution`_\n\n"
-            "Some `task`_ s are dummy tasks have no associated `ecf script`_ file.\n"
+            "Some `task`_\\ s are dummy tasks have no associated `ecf script`_ file.\n"
             "To disable error message for these tasks please add a variable called ECF_DUMMY_TASK to them.\n"
             "Checking is done in conjunction with the class :py:class:`ecflow.JobCreationCtrl`.\n"
             "If no node path is set on class JobCreationCtrl then all tasks are checked.\n"
             "In the case where we want to check all tasks, use the convenience function that take no arguments.\n"
-            "\nUsage::\n\n"
+            "\nUsage:\n\n"
+            ".. code-block:: python\n\n"
             "   defs = Defs('my.def')                     # specify the defs we want to check, load into memory\n"
             "   ...\n"
             "   print(defs.check_job_creation())          # Check job generation for all tasks\n"
@@ -969,11 +1022,11 @@ const char* DefsDoc::check_job_creation_doc()
 const char* DefsDoc::generate_scripts_doc()
 {
    return
-            "Automatically generate template `ecf script`_ s for this definition\n"
-            "Will automatically add `child command`_ s for `event`_, `meter`_ and `label`_ s.\n"
+            "Automatically generate template `ecf script`_\\ s for this definition\n"
+            "Will automatically add `child command`_\\ s for `event`_\\ s, `meter`_\\ s and `label`_\\ s.\n"
             "This allows the definition to be refined with out worrying about the scripts.\n"
             "However it should be noted that, this will create a lot of *duplicated* script contents\n"
-            "i.e in the absence of `event`_ s, `meter`_ s and `label`_ s, most of generated `ecf script`_ files will\n"
+            "i.e in the absence of `event`_\\ s, `meter`_\\ s and `label`_\\ s, most of generated `ecf script`_ files will\n"
             "be the same. Hence should only be used an aid to debugging the definition.\n"
             "It uses the contents of the definition to parameterise what gets\n"
             "generated, and the location of the files. Will throw Exceptions for errors.\n"
@@ -989,7 +1042,8 @@ const char* DefsDoc::generate_scripts_doc()
             "                       and assume this accessible on the path.\n"
             "- ECF_DUMMY_TASK: Will not generated scripts for this task.\n"
             "- SLEEP: Uses this variable to delay time between calls to child commands, if not specified uses delay of one second\n\n"
-            "\nUsage::\n\n"
+            "\nUsage:\n\n"
+            ".. code-block:: python\n\n"
             "   defs = ecflow.Defs()\n"
             "   suite = defs.add_suite('s1')\n"
             "   suite.add_variable('ECF_HOME','/user/var/home')\n"
@@ -1005,14 +1059,15 @@ const char* DefsDoc::generate_scripts_doc()
 const char* DefsDoc::check()
 {
    return
-            "Check `trigger`_ and `complete expression`_ s and `limit`_ s\n\n"
+            "Check `trigger`_ and `complete expression`_\\ s and `limit`_\\ s\n\n"
             "* Client Side: The client side can specify externs. Hence all node path references\n"
-            "  in `trigger`_ expressions, and `inlimit`_ references to `limit`_ s, that are\n"
-            "  unresolved and which do *not* appear in `extern`_ s are reported as errors\n"
+            "  in `trigger`_ expressions, and `inlimit`_ references to `limit`_\\ s, that are\n"
+            "  unresolved and which do *not* appear in `extern`_\\ s are reported as errors\n"
             "* Server Side: The server does not store externs. Hence all unresolved references\n"
             "  are reported as errors\n\n"
             "Returns a non empty string for any errors or warning\n"
-            "\nUsage::\n\n"
+            "\nUsage:\n\n"
+            ".. code-block:: python\n\n"
             "   # Client side\n"
             "   defs = Defs('my.def')        # Load my.def from disk\n"
             "   ....\n"
@@ -1033,7 +1088,8 @@ const char* DefsDoc::simulate() {
          "The simulator will analyse the definition, and simulate the ecflow server.\n"
          "Allowing time dependencies that span several months, to be simulated in a few seconds.\n"
          "Ecflow allows the use of verify attributes. This example show how we can verify the number of times\n"
-         "a task should run, given a start(optional) and end time(optional)::\n\n"
+         "a task should run, given a start(optional) and end time(optional):\n\n"
+         ".. code-block:: shell\n\n"
          "  suite cron3              # use real clock otherwise clock starts when the simulations starts.\n"
          "     clock real  1.1.2006  # define a start date for deterministic behaviour\n"
          "     endclock   13.1.2006  # When to finish. end clock is *only* used for the simulator\n"
@@ -1055,7 +1111,8 @@ const char* DefsDoc::simulate() {
          "use 1 hour resolution. This needs to be taken into account when specifying the verify attribute\n"
          "If the simulation does not complete it creates  defs.flat and  defs.depth files.\n"
          "This provides clues as to the state of the definition at the end of the simulation\n"
-         "\nUsage::\n\n"
+         "\nUsage:\n\n"
+         ".. code-block:: python\n\n"
          "   defs = Defs('my.def')        # specify the defs we want to simulate\n"
          "   ....\n"
          "   theResults = defs.simulate()\n"
@@ -1067,7 +1124,8 @@ const char* DefsDoc::get_server_state()
 {
    return
             "Returns the `ecflow_server`_ state: See `server states`_\n\n"
-            "\nUsage::\n\n"
+            "\nUsage:\n\n"
+            ".. code-block:: python\n\n"
             "   try:\n"
             "       ci = Client()           # use default host(ECF_HOST) & port(ECF_PORT)\n"
             "       ci.shutdown_server()\n"
