@@ -33,18 +33,20 @@ const char* NodeAttrDoc::variable_doc()
             "      string name: the name of the variable\n"
             "      string value: The value of the variable\n\n"
             "   Edit(dict,kwarg) # alternative that allows multiple variables\n"
-            "\nUsage::\n\n"
+            "\nUsage:\n\n"
+            ".. code-block:: python\n\n"
             "   ...\n"
             "   var = Variable('ECF_JOB_CMD','/bin/sh %ECF_JOB% &')\n"
             "   task.add_variable(var)\n"
             "   task.add_variable('JOE','90')\n\n"
-            "The following use example of using Edit, which allow multiple variables to added at the same time ::\n\n"
+            "The following use example of using Edit, which allow multiple variables to added at the same time :\n\n"
+            ".. code-block:: python\n\n"
             "   t = Task('t1',\n"
             "             Edit({ 'a':'y', 'b':'bb'}, c='v',d='b'),\n"
             "             Edit({ 'e':1100, 'f':'bb'}),\n"
             "             Edit(g='d'),\n"
             "             Edit(h='1'))\n\n"
-            "::\n\n"
+            ".. code-block:: python\n\n"
             "  defs = Defs(\n"
             "            Suite('s1'),\n"
             "            Edit(SLEEP='1')) # Add user variable to definition\n"
@@ -74,7 +76,8 @@ const char* NodeAttrDoc::zombie_doc()
             "      ZombieUserActionType  : One of [ fob, fail, block, remove, adopt ]\n"
             "      int lifetime<optional>: Defines the life time in seconds of the zombie in the server.\n"
             "                              On expiration, zombie is removed automatically\n"
-            "\nUsage::\n\n"
+            "\nUsage:\n\n"
+            ".. code-block:: python\n\n"
             "   # Add a zombie attribute so that child commands(i.e ecflow_client --init)\n"
             "   # will fail the job if it is a zombie process.\n"
             "   s1 = Suite('s1')\n"
@@ -89,7 +92,7 @@ const char* NodeAttrDoc::zombie_doc()
 const char* NodeAttrDoc::zombie_type_doc()
 {
    return
-            "`zombie`_ s are running jobs that fail authentication when communicating with the `ecflow_server`_.\n\n"
+            "`zombie`_\\ s are running jobs that fail authentication when communicating with the `ecflow_server`_.\n\n"
             "See class `zombie type`_ and :py:class:`ecflow.ZombieAttr` for further information.\n"
             ;
 }
@@ -103,15 +106,15 @@ const char* NodeAttrDoc::zombie_user_action_type_doc()
             "- fob:    The `child command`_ always succeeds, i.e allows job to complete without blocking\n"
             "- fail:   The `child command`_ is asked to fail.\n"
             "- block:  The `child command`_ is asked to block.\n"
-            "          This is the default action for init,complete and abort child commands\n"
+            "  This is the default action for init,complete and abort child commands\n"
             "\nserver side:\n\n"
-            "- adopt:  Allows the password supplied with the `child command`_ s, to be adopted by the server\n"
+            "- adopt:  Allows the password supplied with the `child command`_\\ s, to be adopted by the server\n"
             "- kill:   Kills the zombie process associated with the `child command`_ using ECF_KILL_CMD.\n"
-            "          path zombies will need to be killed manually. If kill is specified for path zombies\n"
-            "          they will be fobed, i.e allowed to complete without blocking the job.\n"
+            "  path zombies will need to be killed manually. If kill is specified for path zombies\n"
+            "  they will be fobed, i.e allowed to complete without blocking the job.\n"
             "- remove: `ecflow_server`_ removes the `zombie`_ from the zombie list.\n"
-            "          The child continues blocking. If the process is still running, the\n"
-            "          `zombie`_ may well re-appear\n\n"
+            "  The child continues blocking. If the process is still running, the\n"
+            "  `zombie`_ may well re-appear\n\n"
             "Note: Only adopt will allow the `child command`_ to continue and change the `node`_ tree\n"
             ;
 }
@@ -119,7 +122,7 @@ const char* NodeAttrDoc::zombie_user_action_type_doc()
 const char* NodeAttrDoc::child_cmd_type_doc()
 {
    return
-            "ChildCmdType represents the different `child command`_ s.\n"
+            "ChildCmdType represents the different `child command`_\\ s.\n"
             "This type is used as a parameter to the class :py:class:`ecflow.ZombieAttr`\n\n"
             "Child commands are called within a `job file`_::\n\n"
             "  ChildCmdType::init     corresponds to : ecflow_client --init=<process_id>\n"
@@ -148,7 +151,8 @@ const char* NodeAttrDoc::label_doc()
             "   Label(name,value)\n"
             "      string name:  The name of the label\n"
             "      string value: The value of the label\n"
-            "\nUsage::\n\n"
+            "\nUsage:\n\n"
+            ".. code-block:: python\n\n"
             "   t1 = Task('t1',\n"
             "             Label('name','value'),  # create Labels in-place\n"
             "             Label('a','b'))\n"
@@ -163,7 +167,7 @@ const char* NodeAttrDoc::limit_doc()
 {
    return
             "`limit`_ provides a simple load management\n\n"
-            "i.e. by limiting the number of `task`_ s submitted by a server.\n"
+            "i.e. by limiting the number of `task`_\\ s submitted by a server.\n"
             "Limits are typically defined at the `suite`_ level, or defined in a\n"
             "separate suite, so that they can be used by multiple suites.\n"
             "Once a limit is defined in a `suite definition`_, you must also assign families/tasks to use\n"
@@ -172,7 +176,8 @@ const char* NodeAttrDoc::limit_doc()
             "   Limit(name,value)\n"
             "      string name: the name of the limit\n"
             "      int   value: The value of the limit\n"
-            "\nUsage::\n\n"
+            "\nUsage:\n\n"
+            ".. code-block:: python\n\n"
             "   limit = Limit('fast', 10)\n"
             "    ...\n"
             "   suite = Suite('s1',\n"
@@ -184,7 +189,8 @@ const char* NodeAttrDoc::limit_doc()
 const char* NodeAttrDoc::inlimit_doc()
 {
    return
-            "`inlimit`_ is used in conjunction with `limit`_ to provide simple load management::\n\n"
+            "`inlimit`_ is used in conjunction with `limit`_ to provide simple load management:\n\n"
+            ".. code-block:: shell\n\n"
             "   suite x\n"
             "      limit fast 1\n"
             "      family f\n"
@@ -204,7 +210,8 @@ const char* NodeAttrDoc::inlimit_doc()
             "                              from the Limit. defaults to 1 if no value specified.\n"
             "      bool limit_this_node_only<optional> : Only limits this node and *NOT* its children\n"
             "                                            Can be used load balance families\n"
-            "\nUsage::\n\n"
+            "\nUsage:\n\n"
+            ".. code-block:: python\n\n"
             "   inlimit = InLimit('fast','/x/f', 2)\n"
             "    ...\n"
             "   family = Family('f1',\n"
@@ -216,16 +223,17 @@ const char* NodeAttrDoc::inlimit_doc()
 const char* NodeAttrDoc::event_doc()
 {
    return
-            "`event`_ s are used as signal mechanism.\n\n"
+            "`event`_\\ s are used as signal mechanism.\n\n"
             "Typically they would be used to signal partial completion of a `task`_\n"
             "and to be able to `trigger`_ another job, which is waiting for this partial completion.\n"
-            "Only tasks can have events that are automatically set via a `child command`_ s, see below.\n"
+            "Only tasks can have events that are automatically set via a `child command`_\\ s, see below.\n"
             "Events are cleared automatically when a `node`_ is re-queued or begun.\n"
             "Suites and Families can have events, but these events must be set via the Alter command\n"
             "Multiple events can be added to a task.\n"
             "An Event has a number and a optional name. Events are typically used\n"
             "in `trigger`_ and `complete expression`_ , to control job creation.\n"
-            "Event are fired within a script/`job file`_, i.e.::\n\n"
+            "Event are fired within a script/`job file`_, i.e.:\n\n"
+            ".. code-block:: shell\n\n"
             "   ecflow_client --init=$$\n"
             "   ecflow_client --event=foo\n"
             "   ecflow_client --complete\n\n"
@@ -235,7 +243,8 @@ const char* NodeAttrDoc::event_doc()
             "   Event(number, optional<name = ''>)\n"
             "      int number            : The number must be >= 0\n"
             "      string name<optional> : If name is given, can only refer to Event by its name\n"
-            "\nUsage::\n\n"
+            "\nUsage:\n\n"
+            ".. code-block:: python\n\n"
             "   event = Event(2,'event_name')\n"
             "   task.add_event(event)\n"
             "   task1.add_event('2')          # create a event '1' and add to the task\n"
@@ -249,7 +258,7 @@ const char* NodeAttrDoc::event_doc()
 const char* NodeAttrDoc::meter_doc()
 {
    return
-            "`meter`_ s can be used to indicate proportional completion of `task`_\n\n"
+            "`meter`_\\ s can be used to indicate proportional completion of `task`_\n\n"
             "They are able to `trigger`_ another job, which is waiting on this proportion.\n"
             "Can also be used to indicate progress of a job. Meters can be used in\n"
             "`trigger`_ and `complete expression`_.\n"
@@ -263,19 +272,23 @@ const char* NodeAttrDoc::meter_doc()
             "- raises IndexError when an invalid Meter is specified\n"
             "\nUsage:\n\n"
             "Using a meter requires:\n\n"
-            "- Defining a meter on a `task`_::\n\n"
+            "- Defining a meter on a `task`_:\n\n"
+            ".. code-block:: python\n\n"
             "     meter = Meter('progress',0,100,100)\n"
             "     task.add_meter(meter)\n\n"
-            "- Updating the corresponding `ecf script`_ file with the meter `child command`_::\n\n"
+            "- Updating the corresponding `ecf script`_ file with the meter `child command`_:\n\n"
+            ".. code-block:: shell\n\n"
             "     ecflow_client --init=$$\n"
             "     for i in 10 20 30 40 50 60 80 100; do\n"
             "         ecflow_client --meter=progress $i\n"
             "         sleep 2 # or do some work\n"
             "     done\n"
             "     ecflow_client --complete\n\n"
-            "- Optionally addition in a `trigger`_ or `complete expression`_ for job control::\n\n"
+            "- Optionally addition in a `trigger`_ or `complete expression`_ for job control:\n\n"
+            "  .. code-block:: shell\n\n"
             "     trigger task:progress ge 60\n\n"
-            "  trigger and complete expression should *avoid* using equality i.e::\n\n"
+            "  trigger and complete expression should *avoid* using equality i.e.:\n\n"
+            "  .. code-block:: shell\n\n"
             "     trigger task:progress == 60\n\n"
             "  Due to network issues the meter event's may **not** arrive in sequential order\n"
             "  hence the `ecflow_server`_ will ignore meter value's, which are less than the current value\n"
@@ -308,7 +321,8 @@ const char* NodeAttrDoc::date_doc()
             "     int year  : represents the year, zero means wild card. year >= 0\n"
             "\nExceptions:\n\n"
             "- raises IndexError when an invalid date is specified\n"
-            "\nUsage::\n\n"
+            "\nUsage:\n\n"
+            ".. code-block:: python\n\n"
             "  date = Date(11,12,2010)  # represent 11th of December 2010\n"
             "  date = Date(1,0,0);      # means the first day of every month of every year\n"
             "  t = Task('t1',\n"
@@ -329,7 +343,8 @@ const char* NodeAttrDoc::day_doc()
             "      string: 'sunday','monday',etc\n"
             "   Day(Days)\n"
             "      Days day: Is an enumerator with represent the days of the week\n"
-            "\nUsage::\n\n"
+            "\nUsage:\n\n"
+            ".. code-block:: python\n\n"
             "   day1 = Day(Days.sunday)\n"
             "   t = Task('t1',\n"
             "           Day('tuesday'))\n"
@@ -341,7 +356,8 @@ const char* NodeAttrDoc::days_enum_doc()
    return
             "This enum is used as argument to a :py:class:`ecflow.Day` class.\n\n"
             "It represents the days of the week\n"
-            "\nUsage::\n\n"
+            "\nUsage:\n\n"
+            ".. code-block:: python\n\n"
             "   day1 = Day(Days.sunday)\n"
             "   day2 = Day(Days.monday)\n"
             "   t = Task('t1',\n"
@@ -378,7 +394,8 @@ const char* NodeAttrDoc::time_doc()
             "      TimeSeries time_series:Similar to constructor above\n"
             "\nExceptions:\n\n"
             "- raises IndexError when an invalid Time is specified\n"
-            "\nUsage::\n\n"
+            "\nUsage:\n\n"
+            ".. code-block:: python\n\n"
             "   time1 = Time( 10,10 )                                                   #  time 10:10 \n"
             "   time2 = Time( TimeSlot(10,10), true)                                    #  time +10:10 \n"
             "   time2 = Time( TimeSlot(10,10), TimeSlot(20,10),TimeSlot(0,10), false )  #  time 10:10 20:10 00:10 \n\n"
@@ -392,7 +409,7 @@ const char* NodeAttrDoc::today_doc()
 {
    return
             "`today`_ is a time dependency that does not wrap to tomorrow.\n\n"
-            "If the `suite`_ s begin time is past the time given for the Today,\n"
+            "If the `suite`_\\ s begin time is past the time given for the Today,\n"
             "then the node is free to run.\n"
             "\nConstructor::\n\n"
             "   Today(hour,minute,relative<optional> = false)\n"
@@ -411,7 +428,8 @@ const char* NodeAttrDoc::today_doc()
             "      TimeSeries time_series: Similar to constructor above\n"
             "\nExceptions:\n\n"
             "- raises IndexError when an invalid Today is specified\n"
-            "\nUsage::\n\n"
+            "\nUsage:\n\n"
+            ".. code-block:: python\n\n"
             "   today1 = Today( 10,10 )                                                   #  today 10:10 \n"
             "   today2 = Today( TimeSlot(10,10) )                                         #  today 10:10 \n"
             "   today3 = Today( TimeSlot(10,10), true)                                    #  today +10:10 \n"
@@ -432,7 +450,8 @@ const char* NodeAttrDoc::late_doc()
             "\nConstructor::\n\n"
             "   Late()\n"
             "   Late(kwargs)\n"
-            "\nUsage::\n\n"
+            "\nUsage:\n\n"
+            ".. code-block:: python\n\n"
             "   # This is interpreted as: The node can stay `submitted`_ for a maximum of 15 minutes\n"
             "   # and it must become `active`_ by 20:00 and the run time must not exceed 2 hours\n"
             "   late = Late()\n"
@@ -460,7 +479,8 @@ const char* NodeAttrDoc::autocancel_doc()
             "      bool relative:   Relative to completion. False means delete the node at the real time specified.\n\n"
             "   Autocancel(days)\n"
             "      int days:        Delete the node 'days' after completion\n"
-            "\nUsage::\n\n"
+            "\nUsage:\n\n"
+            ".. code-block:: python\n\n"
             "   attr = Autocancel( 1,30, true )              # delete node 1 hour and 30 minutes after completion\n"
             "   attr = Autocancel( TimeSlot(0,10), true )    # delete node 10 minutes after completion\n"
             "   attr = Autocancel( TimeSlot(10,10), false )  # delete node at 10:10 after completion\n"
@@ -494,7 +514,8 @@ const char* NodeAttrDoc::autoarchive_doc()
             "   AutoArchive(days,idle)\n"
             "      int days:      archive the node after 'days' elapsed \n"
             "      bool idle:     True archive if node queued,aborted and complete, False means archive after completion only\n\n"
-            "\nUsage::\n\n"
+            "\nUsage:\n\n"
+            ".. code-block:: python\n\n"
             "   attr = Autoarchive( 1,30, true )              # archive node 1 hour and 30 minutes after completion\n"
             "   attr = Autoarchive( TimeSlot(0,10), true )    # archive node 10 minutes after completion\n"
             "   attr = Autoarchive( TimeSlot(10,10), false )  # archive node at 10:10 after completion\n"
@@ -516,7 +537,8 @@ const char* NodeAttrDoc::autorestore_doc()
             "If the node is suspended or any of its parent are suspended then then the archive does not happen.\n"
             "\nConstructor::\n\n"
             "   Autorestore( list of paths )\n"
-            "\nUsage::\n\n"
+            "\nUsage:\n\n"
+            ".. code-block:: python\n\n"
             "   attr = Autorestore( ['/s1/f1'] )           # restore archived node at /s1/f1\n"
             "   attr = Autorestore( ['/s1/f1','/s1/f2'] )  # restore archived node at /s1/f1 and /s1/f2\n"
             ;
@@ -547,7 +569,8 @@ const char* NodeAttrDoc::repeat_date_doc()
             "      int delta<optional>: default = 1, Always in days. The increment used to update the date\n"
             "\nException:\n\n"
             "- Throws a RuntimeError if start/end are not valid dates\n"
-            "\nUsage::\n\n"
+            "\nUsage:\n\n"
+            ".. code-block:: python\n\n"
             "   rep = RepeatDate('YMD', 20050130, 20050203 )\n"
             "   rep = RepeatDate('YMD', 20050130, 20050203, 2)\n"
             "   t = Task('t1',\n"
@@ -562,7 +585,8 @@ const char* NodeAttrDoc::repeat_date_list_doc()
             "A node can only have one `repeat`_.\n"
             "The repeat name can be referenced in `trigger`_ expressions.\n"
             "The trigger expression referencing a RepeatDateList will use date arithmetic\n"
-            "Here (/suite/family:YMD + 1) uses date arithmetic only, the result is still an integer\n\n"
+            "Here (/suite/family:YMD + 1) uses date arithmetic only, the result is still an integer:\n\n"
+            ".. code-block:: shell\n\n"
             "   trigger /suite/family:YMD + 1 > 20190101\n"
             "\nConstructor::\n\n"
             "   RepeatDateList(variable,list)\n"
@@ -571,7 +595,8 @@ const char* NodeAttrDoc::repeat_date_list_doc()
             "      list list_of_int:    Arbitrary list of integers following a yyyymmdd format\n"
             "\nException:\n\n"
             "- Throws a RuntimeError if list of integers are not valid dates\n"
-            "\nUsage::\n\n"
+            "\nUsage:\n\n"
+            ".. code-block:: python\n\n"
             "   rep = RepeatDateList('YMD', [20050130, 20050203] )\n"
             "   t = Task('t1',\n"
             "            RepeatDateList('YMD',[20050130, 20050203] ))\n"
@@ -591,7 +616,8 @@ const char* NodeAttrDoc::repeat_integer_doc()
             "      int start:           Start integer value\n"
             "      int end:             End end integer value\n"
             "      int step<optional>:  Default = 1, The step amount\n"
-            "\nUsage::\n\n"
+            "\nUsage:\n\n"
+            ".. code-block:: python\n\n"
             "   t = Task('t1',\n"
             "            RepeatInteger('HOUR', 6, 24, 6 ))\n"
             ;
@@ -608,7 +634,8 @@ const char* NodeAttrDoc::repeat_enumerated_doc()
             "      string variable:     The name of the repeat. The current enumeration index can be\n"
             "                           referenced in trigger expressions using the variable name\n"
             "      vector list:         The list of enumerations\n"
-            "\nUsage::\n\n"
+            "\nUsage:\n\n"
+            ".. code-block:: python\n\n"
             "   t = Task('t1',\n"
             "            RepeatEnumerated('COLOR', [ 'red', 'green', 'blue' ] ))\n"
             ;
@@ -625,7 +652,8 @@ const char* NodeAttrDoc::repeat_string_doc()
             "      string variable:     The name of the repeat. The current index of the string list can be\n"
             "                           referenced in trigger expressions using the variable name\n"
             "      vector list:         The list of enumerations\n"
-            "\nUsage::\n\n"
+            "\nUsage:\n\n"
+            ".. code-block:: python\n\n"
             "   t = Task('t1',\n"
             "            RepeatString('COLOR', [ 'red', 'green', 'blue' ] ))\n"
             ;
@@ -639,7 +667,8 @@ const char* NodeAttrDoc::repeat_day_doc()
             "\nConstructor::\n\n"
             "   RepeatDay(step)\n"
             "      int step:     The step.\n"
-            "\nUsage::\n\n"
+            "\nUsage:\n\n"
+            ".. code-block:: python\n\n"
             "   t = Task('t1',\n"
             "             RepeatDay( 1 ))\n"
             ;
@@ -663,7 +692,8 @@ const char* NodeAttrDoc::cron_doc()
             "        months=list of ints)\n"
             "\nExceptions:\n\n"
             "- raises IndexError || RuntimeError when an invalid cron is specified\n"
-            "\nUsage::\n\n"
+            "\nUsage:\n\n"
+            ".. code-block:: python\n\n"
             "    cron = Cron('+00:00 23:00 00:30', days_of_week=[0,1,2,3,4,5,6],days_of_month=[1,2,3,4,5,6], months=[1,2,3,4,5,6])\n\n"
             "    # Here '+' means relative to begin or re-queue time\n"
             "    cron = Cron('+01:30',days_of_week=[0,1,2,3,4,5,6])\n\n"
@@ -711,7 +741,8 @@ const char* NodeAttrDoc::clock_doc()
             "\n"
             "\nExceptions:\n\n"
             "- raises IndexError when an invalid Clock is specified\n"
-            "\nUsage::\n\n"
+            "\nUsage:\n\n"
+            ".. code-block:: python\n\n"
             "   suite = Suite('s1')\n"
             "   clock = Clock(1,1,2012,False)\n"
             "   clock.set_gain(1,10,True)\n"
