@@ -50,7 +50,7 @@ public:
 	void active(bool);
 	bool active() const {return active_;}
 
-	virtual VModelData* data() const = 0;
+    virtual VModelData* getData() const = 0;
 	virtual QModelIndex infoToIndex(VInfo_ptr,int column=0) const;
 	virtual QModelIndex nodeToIndex(const VNode*,int column=0) const=0;
     virtual QModelIndex attributeToIndex(const VAttribute* a, int column=0) const=0;
@@ -80,7 +80,7 @@ protected:
 	void clean();
 	bool hasData() const;
 
-    virtual void resetStateFilter(bool broadcast) {}
+    virtual void resetStateFilter(bool /*broadcast*/) {}
 	virtual QModelIndex serverToIndex(ServerHandler*) const=0;
 
 	bool active_{false};
