@@ -73,21 +73,16 @@ AbstractSearchLine::AbstractSearchLine(QWidget* parent) :
     auto *shortcut = new QShortcut(ctrlg, parent); // should be destroyed by parent
     connect(shortcut, SIGNAL(activated()), this, SLOT(slotFindNext()));
 
-	status_=true;
-
 	setFocusProxy(searchLine_);
 
 	// set the menu on the Options toolbutton
-	caseSensitive_ = false;
-	wholeWords_    = false;
-	highlightAll_  = false;
 	auto *menu=new QMenu(this);
 	menu->addAction(actionCaseSensitive_);
 	menu->addAction(actionWholeWords_);
 	menu->addAction(actionHighlightAll_);
 	optionsTb_->setMenu(menu);
 
-    matchModeCb_->setMatchMode(StringMatchMode::ContainsMatch);  // set the default match mode
+    matchModeCb_->setMatchMode(StringMatchMode(StringMatchMode::ContainsMatch));  // set the default match mode
     //matchModeChanged(1);  // dummy call to initialise the 'whole words' option state
 
     setConfirmSearch(false);
