@@ -27,7 +27,7 @@ VNodeList* ChangeNotifyModel::data()
 	return data_;
 }
 
-void ChangeNotifyModel::setData(VNodeList *data)
+void ChangeNotifyModel::resetData(VNodeList *data)
 {
 	beginResetModel();
 
@@ -89,11 +89,11 @@ QVariant ChangeNotifyModel::data( const QModelIndex& index, int role ) const
 {
 	if(!index.isValid() || !hasData())
     {
-		return QVariant();
+		return {};
 	}
 	int row=index.row();
 	if(row < 0 || row >= data_->size())
-		return QVariant();
+		return {};
 
 	if(role == Qt::DisplayRole)
 	{
@@ -103,7 +103,7 @@ QVariant ChangeNotifyModel::data( const QModelIndex& index, int role ) const
 		switch(index.column())
 		{
 		case 0:
-			return QString::fromStdString(item->server());
+            return QString::fromStdString(item->serverName());
 			break;
 		case 1:
 			return QString::fromStdString(item->path());
@@ -116,7 +116,7 @@ QVariant ChangeNotifyModel::data( const QModelIndex& index, int role ) const
 		}
 	}
 
-	return QVariant();
+	return {};
 }
 
 QVariant ChangeNotifyModel::headerData( const int section, const Qt::Orientation orient , const int role ) const
@@ -124,27 +124,17 @@ QVariant ChangeNotifyModel::headerData( const int section, const Qt::Orientation
 	if ( orient != Qt::Horizontal || (role != Qt::DisplayRole &&  role != Qt::ToolTipRole))
       		  return QAbstractItemModel::headerData( section, orient, role );
 
-   	if(role == Qt::DisplayRole)
+    if(role == Qt::DisplayRole || role== Qt::ToolTipRole)
    	{
    		switch ( section )
    		{
    		case 0: return tr("Server");
    		case 1: return tr("Node");
    		case 2: return tr("Time of change");
-   		default: return QVariant();
+   		default: return {};
    		}
    	}
-   	else if(role== Qt::ToolTipRole)
-   	{
-   		switch ( section )
-   		{
-   		case 0: return tr("Server");
-   		case 1: return tr("Node");
-   		case 2: return tr("Time of change");
-   		default: return QVariant();
-   		}
-   	}
-    return QVariant();
+    return {};
 }
 
 QModelIndex ChangeNotifyModel::index( int row, int column, const QModelIndex & parent ) const
@@ -164,7 +154,7 @@ QModelIndex ChangeNotifyModel::index( int row, int column, const QModelIndex & p
 
 }
 
-QModelIndex ChangeNotifyModel::parent(const QModelIndex &child) const
+QModelIndex ChangeNotifyModel::parent(const QModelIndex &/*child*/) const
 {
 	return {};
 }
@@ -210,7 +200,7 @@ void ChangeNotifyModel::slotBeginRemoveRow(int row)
 	beginRemoveRows(QModelIndex(),row,row);
 }
 
-void ChangeNotifyModel::slotEndRemoveRow(int row)
+void ChangeNotifyModel::slotEndRemoveRow(int /*row*/)
 {
 	endRemoveRows();
 }
