@@ -26,16 +26,11 @@ CommandDesignerWidget::CommandDesignerWidget(QWidget *parent) : QWidget(parent),
 {
 	setupUi(this);
 
-
 	//at least for now, all commands will start with 'ecflow_client' and end with '<full_name>'
 	commandLineEdit_->setText("ecflow_client  <full_name>");
 	//commandLineEdit_->installEventFilter(this);
 	commandLineEdit_->setFocus();
 
-	haveSetUpDefaultCommandLine_ = false;
-	inCommandEditMode_           = false;
-	saveCommandsOnExit_          = false;
-
 	addToContextMenuCb_->setChecked(true);  // by default, suggest saving to context menu
 
 	// ensure the Save button is in the right state
@@ -43,7 +38,6 @@ CommandDesignerWidget::CommandDesignerWidget(QWidget *parent) : QWidget(parent),
 
 	saveNameLineEdit_->setPlaceholderText(tr("Unnamed"));
 
-	currentCommandSaved_ = false;
 	refreshSavedCommandList();
 
 
@@ -553,7 +547,7 @@ void CommandDesignerWidget::on_editCommandButton__clicked()
 }
 
 
-void CommandDesignerWidget::on_savedCommandsTable__cellDoubleClicked(int row, int column)
+void CommandDesignerWidget::on_savedCommandsTable__cellDoubleClicked(int /*row*/, int /*column*/)
 {
 	on_editCommandButton__clicked();  // same as selecting a cell and clicking 'edit'
 }
@@ -636,7 +630,7 @@ void CommandDesignerWidget::addCommandToSavedList(CustomCommand *command, int ro
 }
 
 
-void CommandDesignerWidget::on_savedCommandsTable__cellClicked(int row, int column)
+void CommandDesignerWidget::on_savedCommandsTable__cellClicked(int /*row*/, int /*column*/)
 {
 	setSavedCommandsButtonStatus();
 }
