@@ -20,6 +20,7 @@
 #include <QVBoxLayout>
 #include <QWidgetAction>
 
+#include "UiLog.hpp"
 #include "VNState.hpp"
 #include "VAttributeType.hpp"
 #include "VConfig.hpp"
@@ -324,6 +325,7 @@ void ServerFilterMenu::clear()
 {
 	Q_FOREACH(QAction* ac,acAllMap_)
 	{
+        allMenu_->removeAction(ac);
 		delete ac;
 	}
 	acAllMap_.clear();
@@ -335,6 +337,7 @@ void ServerFilterMenu::clearFavourite()
 {
 	Q_FOREACH(QAction* ac,acFavMap_)
 	{
+        menu_->removeAction(ac);
 		delete ac;
 	}
 	acFavMap_.clear();
@@ -442,7 +445,10 @@ void ServerFilterMenu::syncActionState(QString name,bool checked)
 //Reset actions state when a new filter is loaded
 void ServerFilterMenu::reload(ServerFilter *filter)
 {
-	if(filter_)
+    // hide to avoid crashing. See ECFLOW-1839
+    menu_->hide();
+
+    if(filter_)
 		filter_->removeObserver(this);
 
 	filter_=filter;
@@ -450,13 +456,18 @@ void ServerFilterMenu::reload(ServerFilter *filter)
 	if(filter_)
 		filter_->addObserver(this);
 
-	reload();
+    reload(false);
 }
 
 //Reset actions state when a new filter is loaded
-void ServerFilterMenu::reload()
+void ServerFilterMenu::reload(bool favouriteBuilt)
 {
-	buildFavourite();
+    // hide to avoid crashing. See ECFLOW-1839
+    menu_->hide();
+
+    if (!favouriteBuilt) {
+        buildFavourite();
+    }
 
 	QMap<QString,QAction*>::const_iterator it=acAllMap_.constBegin();
 	while(it != acAllMap_.constEnd())
@@ -494,27 +505,27 @@ void ServerFilterMenu::reload()
 void ServerFilterMenu::notifyServerListChanged()
 {
 	init();
-	reload();
+    reload(true);
 }
 
-void ServerFilterMenu::notifyServerListFavouriteChanged(ServerItem* item)
+void ServerFilterMenu::notifyServerListFavouriteChanged(ServerItem*)
 {
-	reload();
+    reload(false);
 }
 
 void ServerFilterMenu::notifyServerFilterAdded(ServerItem*)
 {
-	reload();
+    reload(false);
 }
 
 void ServerFilterMenu::notifyServerFilterRemoved(ServerItem*)
 {
-	reload();
+    reload(false);
 }
 
 void ServerFilterMenu::notifyServerFilterChanged(ServerItem*)
 {
-	reload();
+    reload(false);
 }
 
 void ServerFilterMenu::notifyServerFilterDelete()
