@@ -96,22 +96,19 @@ void HistoryItemWidget::clearContents()
 
 void HistoryItemWidget::infoReady(VReply* reply)
 {
-    model_->setData(reply->text());
+    model_->resetData(reply->text());
     adjustColumnSize();
     fileLabel_->update(reply,"(Last 100 lines)");
     treeView_->scrollTo(model_->lastIndex());
     checkActionState();
 }
 
-void HistoryItemWidget::infoProgress(VReply* reply)
+void HistoryItemWidget::infoProgress(VReply*)
 {
-    QString s=QString::fromStdString(reply->text());
 }
 
-void HistoryItemWidget::infoFailed(VReply* reply)
+void HistoryItemWidget::infoFailed(VReply*)
 {
-    QString s=QString::fromStdString(reply->errorText());
-
     checkActionState();
 }
 
