@@ -64,7 +64,7 @@ void HtmlEdit::updateFont()
 {
     if(fontProp_)
     {
-        QFont f=fontProp_->value().value<QFont>();
+        auto f=fontProp_->value().value<QFont>();
         if(font() != f)
             setFont(f);
     }
