@@ -58,25 +58,18 @@ public:
 
     bool isSuspended() const {return suspended_;}
     bool keepServerDataOnLoad() const {return keepServerDataOnLoad_;}
-    virtual void notifyInfoChanged(const std::string& path) {}
+    virtual void notifyInfoChanged(const std::string& /*path*/) {}
     virtual void rerender() {}
 
 	//From VTaskObserver
     void taskChanged(VTask_ptr) override {}
 
-	//From VInfoPresenter
-    void infoReady(VReply*) override {}
-    void infoFailed(VReply*) override {}
-    void infoProgress(VReply*) override {}
-    void infoProgressStart(int min,int max,const std::string& text) {}
-    void infoProgress(int value,const std::string& text) {}
-
 	//From NodeObserver
 	void notifyBeginNodeChange(const VNode*, const std::vector<ecf::Aspect::Type>&,const VNodeChange&) override;
 	void notifyEndNodeChange(const VNode*, const std::vector<ecf::Aspect::Type>&,const VNodeChange&) override {}
 
-    virtual void writeSettings(VComboSettings* vs) {}
-    virtual void readSettings(VComboSettings* vs) {}
+    virtual void writeSettings(VComboSettings*) {}
+    virtual void readSettings(VComboSettings*) {}
 
 protected:
 	void adjust(VInfo_ptr);
@@ -85,7 +78,7 @@ protected:
     void relayInfoPanelCommand(VInfo_ptr info,QString cmd);
     void relayDashboardCommand(VInfo_ptr info,QString cmd);
 
-    virtual void clear();
+    void clear();
     virtual void updateState(const ChangeFlags&)=0;
 
 	//Notifications about the server changes
@@ -117,7 +110,7 @@ class InfoPanelItemFactory
 {
 public:
 	explicit InfoPanelItemFactory(const std::string&);
-	virtual ~InfoPanelItemFactory();
+    virtual ~InfoPanelItemFactory() = default;
 
     virtual InfoPanelItem* make() = 0;
     static InfoPanelItem* create(const std::string& name);
