@@ -25,6 +25,7 @@
 #include "UiLog.hpp"
 #include "UIDebug.hpp"
 #include "ViewerUtil.hpp"
+#include "VConfig.hpp"
 #include "VFileInfo.hpp"
 #include "VFileTransfer.hpp"
 #include "VSettings.hpp"
@@ -58,7 +59,7 @@
 //
 //=======================================================
 
-LogLoadWidget::LogLoadWidget(QWidget *parent) :
+LogLoadWidget::LogLoadWidget(QWidget */*parent*/) :
     ui_(new Ui::LogLoadWidget)
 {
     ui_->setupUi(this);
@@ -152,15 +153,6 @@ LogLoadWidget::LogLoadWidget(QWidget *parent) :
     connect(viewHandler_,SIGNAL(timeRangeReset()),
             this,SLOT(periodWasReset()));
 
-    //logInfo label
-    ui_->logInfoLabel->setProperty("fileInfo","1");
-    ui_->logInfoLabel->setWordWrap(true);
-    ui_->logInfoLabel->setMargin(2);
-    ui_->logInfoLabel->setAlignment(Qt::AlignLeft|Qt::AlignVCenter);
-    ui_->logInfoLabel->setAutoFillBackground(true);
-    ui_->logInfoLabel->setFrameShape(QFrame::StyledPanel);
-    ui_->logInfoLabel->setTextInteractionFlags(Qt::LinksAccessibleByMouse|Qt::TextSelectableByKeyboard|Qt::TextSelectableByMouse);
-
     // log mode
     ui_->logModeCombo->addItem("Current log","latest");
     ui_->logModeCombo->addItem("Archived log","archive");
@@ -177,11 +169,20 @@ LogLoadWidget::LogLoadWidget(QWidget *parent) :
     connect(ui_->loadFileTb,SIGNAL(clicked()),
             this,SLOT(slotLoadCustomFile()));
 
+    // the icon for this button changes according to state
+    ui_->expandFileInfoTb->setIcon(ViewerUtil::makeExpandIcon(false));
+    ui_->expandFileInfoTb->setMaximumSize(QSize(16, 16));
+    expandFileInfoProp_ = VConfig::instance()->find("panel.timeline.expandFileInfo");
+    Q_ASSERT(expandFileInfoProp_);
+    bool expandSt = expandFileInfoProp_->value().toBool();
+    ui_->expandFileInfoTb->setChecked(expandSt);
+    connect(ui_->expandFileInfoTb,SIGNAL(clicked(bool)),
+            this,SLOT(slotExpandFileInfo(bool)));
+    slotExpandFileInfo(expandSt);
 }
 
 LogLoadWidget::~LogLoadWidget()
-{
-}
+= default;
 
 //void LogLoadWidget::initSplitter()
 //{
@@ -205,14 +206,14 @@ void LogLoadWidget::clear()
     beingCleared_=true;
     if(fileTransfer_)
     {
-        fileTransfer_->stopTransfer();
+        fileTransfer_->stopTransfer(true);
         ui_->messageLabel->stopLoadLabel();
     }
 
     ui_->messageLabel->clear();
     ui_->messageLabel->hide();
 
-    ui_->logInfoLabel->setText(QString());
+    ui_->logInfoLabel->clearIt();
 
     viewHandler_->clear();
     logModel_->clearData();
@@ -249,13 +250,13 @@ void LogLoadWidget::clearData(bool usePrevState)
     beingCleared_=true;
     if(fileTransfer_)
     {
-        fileTransfer_->stopTransfer();
+        fileTransfer_->stopTransfer(true);
         ui_->messageLabel->stopLoadLabel();
     }
 
     ui_->messageLabel->clear();
     ui_->messageLabel->hide();
-    ui_->logInfoLabel->setText(QString());
+    ui_->logInfoLabel->clearIt();
 
     viewHandler_->clear();
     logModel_->clearData();
@@ -281,18 +282,16 @@ void LogLoadWidget::clearData(bool usePrevState)
 
 void LogLoadWidget::updateInfoLabel(bool showDetails)
 {
-    QColor col(39,49,101);
-    QString txt;
+    QString txt, compactTxt;
 
     auto data = viewHandler_->data();
 
     if(logMode_ == LatestMode)
     {
-        txt= Viewer::formatBoldText("Log file: ",col) + logFile_;
-
-        txt+=Viewer::formatBoldText(" Server: ",col) + serverName_ +
-             Viewer::formatBoldText(" Host: ",col) + host_ +
-             Viewer::formatBoldText(" Port: ",col) + port_;
+        txt= FileInfoLabel::formatKwPair("Log file", logFile_) +
+             FileInfoLabel::formatKwPair(" Server", serverName_) +
+             FileInfoLabel::formatKwPair(" Host", host_) +
+             FileInfoLabel::formatKwPair(" Port", port_);
 
         if(showDetails)
         {
@@ -301,23 +300,23 @@ void LogLoadWidget::updateInfoLabel(bool showDetails)
                 if(localLog_)
                 {
                     VFileInfo fi(logFile_);
-                    txt+=Viewer::formatBoldText(" Size: ",col) + fi.formatSize();
+                    txt+=FileInfoLabel::formatKwPair(" Size", fi.formatSize());
                 }
-                else
+                else if (tmpLogFile_)
                 {
                     VFileInfo fi(QString::fromStdString(tmpLogFile_->path()));
-                    txt+=Viewer::formatBoldText(" Size: ",col) + fi.formatSize();
+                    txt+=FileInfoLabel::formatKwPair(" Size", fi.formatSize());
                 }
             }
 
-            txt+=Viewer::formatBoldText(" Source: ",col);
+            txt+=FileInfoLabel::formatKey(" Source");
 
             //fetch method and time
             if(localLog_)
             {
                 txt+=" read from disk ";
                 if(data->loadedAt().isValid())
-                    txt+=Viewer::formatBoldText(" at ",col) + FileInfoLabel::formatDate(data->loadedAt());
+                    txt+=FileInfoLabel::formatHighlight(" at ") + FileInfoLabel::formatDate(data->loadedAt());
             }
             else
             {
@@ -330,7 +329,7 @@ void LogLoadWidget::updateInfoLabel(bool showDetails)
                     txt+=" fetch failed from remote host ";
                 }
                 if(transferredAt_.isValid())
-                    txt+=Viewer::formatBoldText(" at ",col) + FileInfoLabel::formatDate(transferredAt_);
+                    txt+=FileInfoLabel::formatHighlight(" at ") + FileInfoLabel::formatDate(transferredAt_);
             }
 
             if(data->loadStatus() == LogLoadData::LoadDone)
@@ -358,6 +357,9 @@ void LogLoadWidget::updateInfoLabel(bool showDetails)
                 }
             }
         }
+
+        VFileInfo fInfo(logFile_);
+        compactTxt = FileInfoLabel::formatKwPair("File", fInfo.fileName());
     }
 
     //archived
@@ -365,35 +367,35 @@ void LogLoadWidget::updateInfoLabel(bool showDetails)
     {
         if(archiveLogList_.loadableCount() == 1)
         {
-           txt= Viewer::formatBoldText("Log file: ",col) + archiveLogList_.firstLoadablePath();
+           txt= FileInfoLabel::formatKwPair("Log file",archiveLogList_.firstLoadablePath());
         }
         else if(archiveLogList_.loadableCount() > 1)
         {
-           txt= Viewer::formatBoldText("Log files: ",col) + "multiple ["+
-                   QString::number(archiveLogList_.loadableCount())  + "]";
+            txt= FileInfoLabel::formatKwPair("Log files", "multiple ["+
+                    QString::number(archiveLogList_.loadableCount())  + "]");
         }
 
-        txt+=Viewer::formatBoldText(" Server: ",col) + serverName_ +
-            Viewer::formatBoldText(" Host: ",col) + host_ +
-            Viewer::formatBoldText(" Port: ",col) + port_;
+        txt+=FileInfoLabel::formatKwPair(" Server", serverName_) +
+             FileInfoLabel::formatKwPair(" Host", host_) +
+             FileInfoLabel::formatKwPair(" Port", port_);
 
         if(showDetails)
         {
             if(data->loadStatus() == LogLoadData::LoadDone)
             {
                 if(archiveLogList_.loadableCount() == 1)
-                    txt+=Viewer::formatBoldText(" Size: ",col) + VFileInfo::formatSize(archiveLogList_.totalSize());
+                    txt+=FileInfoLabel::formatKwPair(" Size", VFileInfo::formatSize(archiveLogList_.totalSize()));
                 else if (archiveLogList_.loadableCount() > 1)
-                    txt+=Viewer::formatBoldText(" Total size: ",col) + VFileInfo::formatSize(archiveLogList_.totalSize());
+                    txt+=FileInfoLabel::formatKwPair(" Total size", VFileInfo::formatSize(archiveLogList_.totalSize()));
             }
-
-            txt+=Viewer::formatBoldText(" Source: ",col);
-            txt+=" read from disk ";
+            txt+=FileInfoLabel::formatKwPair(" Source", "read from disk ");
         }
 
+        compactTxt = FileInfoLabel::formatKwPair("Log files", "multiple ["+
+                           QString::number(archiveLogList_.loadableCount())  + "]");
     }
 
-    ui_->logInfoLabel->setText(txt);
+    ui_->logInfoLabel->update(txt, compactTxt);
 
     checkButtonState();
 }
@@ -589,7 +591,7 @@ void LogLoadWidget::loadLatest(bool usePrevState)
     if(!fInfo.exists())
     {
         localLog_=false;
-        tmpLogFile_=VFile::createTmpFile(true); //will be deleted automatically
+        //tmpLogFile_=VFile::createTmpFile(true); //will be deleted automatically
         ui_->messageLabel->showInfo("Fetching file from remote host ...");
         ui_->messageLabel->startLoadLabel(true);
 
@@ -607,8 +609,11 @@ void LogLoadWidget::loadLatest(bool usePrevState)
                     this,SLOT(slotFileTransferStdOutput(QString)));
         }
 
-        fileTransfer_->transfer(logFile_,host_,QString::fromStdString(tmpLogFile_->path()),
-                                maxReadSize_,remoteUid_);
+        if (VConfig::instance()->proxychainsUsed()) {
+           fileTransfer_->transferLocalViaSocks(logFile_,VFileTransfer::LastBytes, maxReadSize_);
+        } else {
+            fileTransfer_->transfer(logFile_,host_,remoteUid_,VFileTransfer::LastBytes, maxReadSize_);
+        }
     }
     // load local file
     else
@@ -660,7 +665,7 @@ void LogLoadWidget::loadArchive()
             loadDone=true;
         }
 
-        catch(std::runtime_error e)
+        catch(const std::runtime_error& e)
         {
             logModel_->endLoadFromReader();
             //logLoaded_=false;
@@ -703,11 +708,15 @@ void LogLoadWidget::slotFileTransferFinished()
     //we are not in a cleared state
     if(!beingCleared_)
     {
+        tmpLogFile_ = fileTransfer_->result();
+        fileTransfer_->clear();
         logTransferred_=true;
         ui_->messageLabel->stopLoadLabel();
         ui_->messageLabel->hide();
         ui_->messageLabel->update();
-        loadCore(QString::fromStdString(tmpLogFile_->path()));
+        if (tmpLogFile_) {
+            loadCore(QString::fromStdString(tmpLogFile_->path()));
+        }
     }
 }
 
@@ -715,6 +724,8 @@ void LogLoadWidget::slotFileTransferFailed(QString err)
 {
     if(!beingCleared_)
     {
+        tmpLogFile_.reset();
+        fileTransfer_->clear();
         logTransferred_=false;
         ui_->messageLabel->stopLoadLabel();
         logLoaded_=false;
@@ -752,7 +763,7 @@ void LogLoadWidget::slotCancelFileTransfer()
 #endif
     if(fileTransfer_)
     {
-        fileTransfer_->stopTransfer();
+        fileTransfer_->stopTransfer(true);
     }
 }
 
@@ -775,7 +786,7 @@ void LogLoadWidget::loadCore(QString logFile)
                            logModel_->logData());
         logModel_->endLoadFromReader();
     }
-    catch(std::runtime_error e)
+    catch(const std::runtime_error& e)
     {
         logModel_->endLoadFromReader();
 
@@ -933,6 +944,18 @@ void LogLoadWidget::resolutionChanged(int)
         viewHandler_->setResolution(LogLoadData::HourResolution);
 }
 
+//-------------------------
+// File info label
+//-------------------------
+
+void LogLoadWidget::slotExpandFileInfo(bool st)
+{
+    Q_ASSERT(expandFileInfoProp_);
+    expandFileInfoProp_->setValue(st);
+    ui_->logInfoLabel->setCompact(!st);
+}
+
+
 void LogLoadWidget::writeSettings(VComboSettings* vs)
 {
 //    int cbIdx=ui_->resCombo->currentIndex();
