@@ -62,10 +62,10 @@ QList<MainWindow*> MainWindow::windows_;
 int MainWindow::maxWindowNum_=25;
 
 #ifdef ECFLOW_LOGVIEW
-LogViewerCom* MainWindow::logCom_=NULL;
+LogViewerCom* MainWindow::logCom_=nullptr;
 #endif
 
-MainWindow::MainWindow(QStringList idLst,QWidget *parent) :
+MainWindow::MainWindow(QStringList /*idLst*/,QWidget *parent) :
     QMainWindow(parent),
     serverSyncNotifyTb_(nullptr)
 {
@@ -83,7 +83,7 @@ MainWindow::MainWindow(QStringList idLst,QWidget *parent) :
     //Create the main layout
     auto* layout=new QVBoxLayout();
     layout->setContentsMargins(0,0,0,0);
-    QWidget *w=new QWidget(this);
+    auto *w=new QWidget(this);
     w->setObjectName("c");
     w->setLayout(layout);
     setCentralWidget(w);
@@ -139,20 +139,18 @@ MainWindow::MainWindow(QStringList idLst,QWidget *parent) :
     //--------------
 
     //Add server list sync notification
-    if(ServerList::instance()->hasSyncChange())
-    {
-        //Add server list sync notification
-        serverSyncNotifyTb_=new QToolButton(this);
-        serverSyncNotifyTb_->setAutoRaise(true);
-        serverSyncNotifyTb_->setToolButtonStyle(Qt::ToolButtonTextBesideIcon);
-        serverSyncNotifyTb_->setIcon(QPixmap(":/viewer/info.svg"));
-        serverSyncNotifyTb_->setText("Server list updated");
-        serverSyncNotifyTb_->setToolTip("Your local copy of the <b>system server list</b> was updated. Click to see the changes.");
-        statusBar()->addWidget(serverSyncNotifyTb_);
-
-        connect(serverSyncNotifyTb_,SIGNAL(clicked(bool)),
+    serverSyncNotifyTb_=new QToolButton(this);
+    serverSyncNotifyTb_->setAutoRaise(true);
+    serverSyncNotifyTb_->setToolButtonStyle(Qt::ToolButtonTextBesideIcon);
+    serverSyncNotifyTb_->setIcon(QPixmap(":/viewer/info.svg"));
+    serverSyncNotifyTb_->setText("Server list updated");
+    serverSyncNotifyTb_->setToolTip("Your local copy of the <b>system server list</b> was updated. Click to see the changes.");
+    statusBar()->addWidget(serverSyncNotifyTb_);
+    serverSyncNotifyTb_->hide();
+    connect(serverSyncNotifyTb_,SIGNAL(clicked(bool)),
             this,SLOT(slotServerSyncNotify(bool)));
-    }
+
+    initServerSyncTbInternal();
 
     //Add notification widget
     auto* chw=new ChangeNotifyWidget(this);
@@ -407,8 +405,6 @@ void MainWindow::slotSelectionChanged(VInfo_ptr info)
 void MainWindow::updateRefreshActions()
 {
     ServerHandler* s=nullptr;
-
-    QString serverName;
     if(selection_)
 	{
         s=selection_->server();
@@ -460,6 +456,23 @@ bool MainWindow::selectInTreeView(VInfo_ptr info)
     return nodePanel_->selectInTreeView(info);
 }
 
+void MainWindow::initServerSyncTbInternal()
+{
+    auto manager = ServerList::instance()->systemFileManager();
+    if(manager && manager->hasInfo())
+    {
+        if (!manager->unfetchedFiles().empty()) {
+            serverSyncNotifyTb_->setIcon(QPixmap(":/viewer/error.svg"));
+            serverSyncNotifyTb_->setText("System server list updated (with some errors)");
+        } else {
+            serverSyncNotifyTb_->setIcon(QPixmap(":/viewer/info.svg"));
+            serverSyncNotifyTb_->setText("System server list updated");
+        }
+        Q_ASSERT(serverSyncNotifyTb_);
+        serverSyncNotifyTb_->show();
+    }
+}
+
 void MainWindow::slotServerSyncNotify(bool)
 {
     if(serverSyncNotifyTb_)
@@ -621,7 +634,7 @@ void MainWindow::openWindow(QStringList idLst,QWidget *fromW)
 
 void MainWindow::showWindows()
 {
-  	Q_FOREACH(MainWindow *win,windows_)
+    for(auto win: windows_)
 		win->show();
 }
 
@@ -650,6 +663,14 @@ void MainWindow::cleanUpOnQuit(MainWindow*)
         win->cleanUpOnQuit();
 }
 
+//Add server list sync notification
+void MainWindow::initServerSyncTb()
+{
+    Q_FOREACH(MainWindow *win,windows_) {
+        win->initServerSyncTbInternal();
+    }
+}
+
 bool MainWindow::aboutToQuit(MainWindow* topWin)
 {
 #if 0
@@ -809,7 +830,7 @@ void MainWindow::reload()
 	}
 }
 
-void MainWindow::saveSession(SessionItem* s)
+void MainWindow::saveSession(SessionItem*)
 {
 
 }
