@@ -94,7 +94,7 @@ void MessageItemWidget::clearContents()
 
 void MessageItemWidget::infoReady(VReply* reply)
 {
-    model_->setData(reply->textVec());
+    model_->resetData(reply->textVec());
 
     //Adjust column size if it is the first run
     if(firstRun && model_->hasData())
@@ -107,14 +107,12 @@ void MessageItemWidget::infoReady(VReply* reply)
     }
 }
 
-void MessageItemWidget::infoProgress(VReply* reply)
+void MessageItemWidget::infoProgress(VReply*)
 {
-    QString s=QString::fromStdString(reply->text());
 }
 
-void MessageItemWidget::infoFailed(VReply* reply)
+void MessageItemWidget::infoFailed(VReply*)
 {
-    QString s=QString::fromStdString(reply->errorText());
 }
 
 void MessageItemWidget::on_actionCopyEntry__triggered()
