@@ -60,7 +60,7 @@ NodeExpressionParser::NodeExpressionParser()
     nameToNodeType_["alias"]=ALIAS;
     nameToNodeType_["node"]=NODE;
 
-    for(std::map<std::string,NodeType>::const_iterator it=nameToNodeType_.begin();  it != nameToNodeType_.end(); ++it)
+    for(auto it=nameToNodeType_.begin();  it != nameToNodeType_.end(); ++it)
     {
         nodeTypeToName_[it->second]=it->first;
     }
@@ -404,6 +404,14 @@ BaseNodeCondition *NodeExpressionParser::parseExpression(bool caseSensitiveStrin
                     result = dateCond;
                 }
 
+                //iso date operator
+                else if (*i_ == "date::<")
+                {
+                    auto *dateCond = new IsoDateLessThanCondition();
+                    funcStack.push_back(dateCond);
+                    result = dateCond;
+                }
+
                 //iso date operator
                 else if (*i_ == "date::>=")
                 {
@@ -412,6 +420,14 @@ BaseNodeCondition *NodeExpressionParser::parseExpression(bool caseSensitiveStrin
                     result = dateCond;
                 }
 
+                //iso date operator
+                else if (*i_ == "date::>")
+                {
+                    auto *dateCond = new IsoDateGreaterThanCondition();
+                    funcStack.push_back(dateCond);
+                    result = dateCond;
+                }
+
                 else if (*i_ == "marked")
                 {
                     auto *uiCond = new UIStateCondition(*i_);
@@ -987,9 +1003,9 @@ bool NodeFlagCondition::execute(VItem* item)
 	return false;
 }
 
-WhatToSearchInOperand::WhatToSearchInOperand(std::string what, bool &attr)
+WhatToSearchInOperand::WhatToSearchInOperand(std::string what, bool &attr) :
+    what_(what)
 {
-    what_ = what;
     searchInAttributes_ = attr;
 }
 
@@ -1087,7 +1103,7 @@ std::string IsoDateCondition::print()
 #else
         return QDateTime::fromMSecsSinceEpoch(secsSinceEpoch_*1000).toUTC().toString(Qt::ISODate).toStdString();
 #endif
-    return std::string();
+    return {};
 }
 
 //==========================================
@@ -1143,6 +1159,35 @@ std::string IsoDateGreaterThanEqualCondition::print()
     return operands_[1]->print() + " >= " + operands_[0]->print();
 }
 
+//==========================================
+//
+// ISO date greater than condition
+//
+//==========================================
+
+bool IsoDateGreaterThanCondition::execute(VItem *node)
+{
+    UI_ASSERT(operands_.size() == 2,"operands size=" <<operands_.size() );
+    Q_ASSERT(operands_[0]);
+    Q_ASSERT(operands_[1]);
+    //The operand order is swapped in popLastNOperands(). So 1 is right, 0 is left here.
+    auto* leftOperand=static_cast<IsoDateCondition*> (operands_[1]);
+    auto* rightOperand=static_cast<IsoDateCondition*> (operands_[0]);
+    Q_ASSERT(leftOperand);
+    Q_ASSERT(rightOperand);
+
+    return leftOperand->secsSinceEpoch(node) > rightOperand->secsSinceEpoch(node);
+}
+
+std::string IsoDateGreaterThanCondition::print()
+{
+    UI_ASSERT(operands_.size() == 2,"operands size=" <<operands_.size() );
+    Q_ASSERT(operands_[0]);
+    Q_ASSERT(operands_[1]);
+    //The operand order is swapped in popLastNOperands(). So 1 is right, 0 is left here.
+    return operands_[1]->print() + " > " + operands_[0]->print();
+}
+
 //==========================================
 //
 // ISO date less than equal condition
@@ -1171,3 +1216,32 @@ std::string IsoDateLessThanEqualCondition::print()
     //The operand order is swapped in popLastNOperands(). So 1 is right, 0 is left here.
     return operands_[1]->print() + " <= " + operands_[0]->print();
 }
+
+//==========================================
+//
+// ISO date less than condition
+//
+//==========================================
+
+bool IsoDateLessThanCondition::execute(VItem *node)
+{
+    UI_ASSERT(operands_.size() == 2,"operands size=" <<operands_.size() );
+    Q_ASSERT(operands_[0]);
+    Q_ASSERT(operands_[1]);
+    //The operand order is swapped in popLastNOperands(). So 1 is right, 0 is left here.
+    auto* leftOperand=static_cast<IsoDateCondition*> (operands_[1]);
+    auto* rightOperand=static_cast<IsoDateCondition*> (operands_[0]);
+    Q_ASSERT(leftOperand);
+    Q_ASSERT(rightOperand);
+
+    return leftOperand->secsSinceEpoch(node) < rightOperand->secsSinceEpoch(node);
+}
+
+std::string IsoDateLessThanCondition::print()
+{
+    UI_ASSERT(operands_.size() == 2,"operands size=" <<operands_.size() );
+    Q_ASSERT(operands_[0]);
+    Q_ASSERT(operands_[1]);
+    //The operand order is swapped in popLastNOperands(). So 1 is right, 0 is left here.
+    return operands_[1]->print() + " < " + operands_[0]->print();
+}
