@@ -219,13 +219,15 @@ class StringMatchCondition : public BaseNodeCondition
 public:
     StringMatchCondition(StringMatchMode::Mode matchMode, bool caseSensitive);
     ~StringMatchCondition() override {if (matcher_) delete matcher_;}
+    StringMatchCondition(const StringMatchCondition&) = delete;
+    StringMatchCondition& operator=(const StringMatchCondition&) = delete;
 
     bool execute(VItem *node) override;
     int  numOperands() override {return 2;}
     std::string print() override {return operands_[0]->print() + " = " + operands_[1]->print();}
     bool operand2IsArbitraryString() override {return true;}
 private:
-    StringMatchBase *matcher_;
+    StringMatchBase *matcher_{nullptr};
 };
 
 // -----------------------------------------------------------------
@@ -440,6 +442,17 @@ public:
     std::string print() override;
 };
 
+class IsoDateGreaterThanCondition : public BaseNodeCondition
+{
+public:
+    IsoDateGreaterThanCondition() = default;
+    ~IsoDateGreaterThanCondition() override = default;
+
+    bool execute(VItem *node) override;
+    int  numOperands() override {return 2;}
+    std::string print() override;
+};
+
 class IsoDateLessThanEqualCondition : public BaseNodeCondition
 {
 public:
@@ -451,6 +464,17 @@ public:
     std::string print() override;
 };
 
+class IsoDateLessThanCondition : public BaseNodeCondition
+{
+public:
+    IsoDateLessThanCondition() = default;
+    ~IsoDateLessThanCondition() override = default;
+
+    bool execute(VItem *node) override;
+    int  numOperands() override {return 2;}
+    std::string print() override;
+};
+
 // -----------------------------------------------------------------
 
 // -----------------
@@ -464,7 +488,7 @@ public:
     ~WhatToSearchInOperand() override;
 
     const std::string& name() const {return what_;}
-    bool execute(VItem* node) override  {return false;} // not called
+    bool execute(VItem* /*node*/) override  {return false;} // not called
     std::string print() override {return what_;}
     const std::string& what() const {return what_;}
 
@@ -484,7 +508,7 @@ public:
     ~WhatToSearchForOperand() override;
 
     std::string name() {return what_;}
-    bool execute(VItem* node) override {return false;} // not called
+    bool execute(VItem* /*node*/) override {return false;} // not called
     std::string print() override {return what_;}
     std::string what() {return what_;}
 
