@@ -45,9 +45,7 @@ int NodePathItem::vPadding_=0;
 
 BcWidget::BcWidget(QWidget* parent) : 
     QWidget(parent),
-	 text_("No selection"),
-    textCol_(Qt::white),
-    textDisabledCol_(QColor(220,220,220))
+    font_(QFont())
 {
     font_=QFont();
     font_.setPointSize(font_.pointSize()-1);
@@ -89,7 +87,7 @@ BcWidget::~BcWidget()
     delete ellipsisItem_;
 }    
 
-void BcWidget::notifyChange(VProperty *p)
+void BcWidget::notifyChange(VProperty*)
 {
     updateSettings();
 }    
@@ -647,7 +645,7 @@ int NodePathItem::adjust(int xp,int yp,int elidedLen)
     visible_=true;
 
     QFontMetrics fm(owner_->font());
-    int len;
+    int len = 0;
     if(elidedLen == 0)
     {
         elidedText_=QString();
@@ -678,7 +676,7 @@ int NodePathItem::rightPos(int xp,int len) const
 int NodePathItem::estimateRightPos(int xp,int elidedLen)
 {
     QFontMetrics fm(owner_->font());
-    int len;
+    int len = 0;
 
     if(elidedLen==0)
         len=ViewerUtil::textWidth(fm,text_);
@@ -708,7 +706,7 @@ void NodePathItem::reset(QString text,QColor bgCol,QColor fontCol,bool hovered)
         borderCol_=bgCol_.darker(240);
 }
 
-void NodePathItem::draw(QPainter  *painter,bool useGrad,int lighter)
+void NodePathItem::draw(QPainter  *painter,bool useGrad,int /*lighter*/)
 {    
     if(!visible_)
         return;
@@ -895,7 +893,7 @@ void NodePathWidget::setMode(Mode mode)
     }
 }
 
-void NodePathWidget::slotContextMenu(const QPoint& pos)
+void NodePathWidget::slotContextMenu(const QPoint& /*pos*/)
 {
 }
 
@@ -1020,7 +1018,7 @@ void NodePathWidget::setPath(VInfo_ptr info)
     // Interactive breadcrumsbs
     //------------------------------------
 
-    Q_ASSERT(mode_ = GuiMode);
+    Q_ASSERT(mode_ == GuiMode);
 
 	//Get the node list including the server
   	std::vector<VNode*> lst;
@@ -1111,25 +1109,23 @@ VInfo_ptr NodePathWidget::nodeAt(int idx)
     Q_ASSERT(mode_ == GuiMode);
     if(mode_ == TextMode)
     {
-        return VInfo_ptr();
+        return {};
     }
 
-    ServerHandler* server=info_->server();
+    if (info_ && info_->server())
+    {
+        if(VNode *n=info_->node()->ancestorAt(idx,VNode::ParentToChildSort))
+        {
+            if(n == info_->node())
+                return info_;
+            else if(n->isServer())
+                return VInfoServer::create(n->server());
+            else
+                return VInfoNode::create(n);
+        }
+    }
 
-	if(info_ && server)
-	{
-		if(VNode *n=info_->node()->ancestorAt(idx,VNode::ParentToChildSort))
-		{
-			if(n == info_->node())
-				return info_;
-			else if(n->isServer())
-				return VInfoServer::create(n->server());
-			else
-				return VInfoNode::create(n);
-		}
-	}
-
-	return VInfo_ptr();
+	return {};
 }
 
 void NodePathWidget::loadMenu(const QPoint& pos,VInfo_ptr p)
@@ -1347,6 +1343,11 @@ void NodePathWidget::notifyServerActivityChanged(ServerHandler* /*server*/)
     //reset();
 }
 
+void NodePathWidget::notifyServerRenamed(ServerHandler*, const std::string& /*oldName*/)
+{
+     reset();
+}
+
 void NodePathWidget::notifyDataLost(VInfo* info)
 {
 #ifdef _UI_NODEPATHWIDGET_DEBUG
@@ -1405,7 +1406,7 @@ void NodePathWidget::writeSettings(VSettings *vs)
 void NodePathWidget::readSettings(VSettings* vs)
 {
 	vs->beginGroup("breadcrumbs");
-    std::string modeStr=vs->get<std::string>("mode","");
+    auto modeStr=vs->get<std::string>("mode","");
 
     if(modeStr == "text")
     {
