@@ -83,10 +83,10 @@ protected:
     int maxWidth_{0};
     int height_;
     int itemHeight_{0};
-    QString text_;
+    QString text_{"No selection"};
     QRect textRect_;
-    QColor textCol_;
-    QColor textDisabledCol_;
+    QColor textCol_{Qt::white};
+    QColor textDisabledCol_{220,220,220};
     QList<NodePathItem*> items_;
     NodePathEllipsisItem* ellipsisItem_;
     
@@ -192,11 +192,12 @@ public:
 	void notifyDefsChanged(ServerHandler* server,const std::vector<ecf::Aspect::Type>&) override;
 	void notifyServerDelete(ServerHandler* server) override;
     void notifyBeginServerClear(ServerHandler* server) override;
-    void notifyEndServerClear(ServerHandler* server) override {}
-    void notifyBeginServerScan(ServerHandler* server,const VServerChange&) override {}
+    void notifyEndServerClear(ServerHandler*) override {}
+    void notifyBeginServerScan(ServerHandler*,const VServerChange&) override {}
     void notifyEndServerScan(ServerHandler* server) override;
 	void notifyServerConnectState(ServerHandler* server) override;
 	void notifyServerActivityChanged(ServerHandler* server) override;
+    void notifyServerRenamed(ServerHandler* server, const std::string& oldName) override;
 
     //From VInfoObserver
     void notifyDelete(VInfo*) override {}
