@@ -40,7 +40,7 @@ QString NodeQueryAttrGroup::query() const
         return "(" + lst.join(" and ") + ")";
     }
 
-    return QString();
+    return {};
 }
 
 bool NodeQueryVarAttrGroup::hasType(VAttributeType* t) const 
@@ -159,7 +159,7 @@ QString NodeQuery::query() const
     else
         return s2;
            
-    return QString();
+    return {};
 }
 
 
@@ -262,6 +262,35 @@ NodeQueryListOption* NodeQuery::stateOption() const
     return op->isList();
 }
 
+
+bool NodeQuery::removeServer(const std::string& serverName)
+{
+    if(servers_.empty()) {
+        return false;
+    }
+    if (servers_.removeAll(QString::fromStdString(serverName)) > 0) {
+        buildQueryString();
+        return true;
+    }
+    return false;
+}
+
+bool NodeQuery::renameServer(const std::string& newName, const std::string& oldName)
+{
+    if(servers_.empty())
+        return false;
+
+    QString sNew = QString::fromStdString(newName);
+    QString sOld = QString::fromStdString(oldName);
+    int idx = servers_.indexOf(sOld);
+    if (idx >= 0) {
+        servers_[idx] = sNew;
+        buildQueryString();
+        return true;
+    }
+    return false;
+}
+
 void NodeQuery::buildQueryString()
 {
 #ifdef _UI_NODEQUERY_DEBUG
@@ -439,8 +468,8 @@ void NodeQuery::load(VSettings* vs)
 	std::vector<std::string> v;
 	vs->get("servers",v);
 	servers_.clear();
-	for(std::vector<std::string>::const_iterator it=v.begin(); it != v.end(); ++it)
-	    servers_ << QString::fromStdString(*it);
+    for(auto & it : v)
+        servers_ << QString::fromStdString(it);
 
 	//allServers_=vs->getAsBool("allServers",allServers_);
 
