@@ -166,7 +166,7 @@ void NodeQueryEngine::run()
     }
     else
     {
-        for(std::vector<ServerHandler*>::const_iterator it=servers_.begin(); it != servers_.end(); ++it)
+        for(auto it=servers_.begin(); it != servers_.end(); ++it)
         {
             ServerHandler *server=*it;
 
@@ -183,7 +183,7 @@ void NodeQueryEngine::run()
     broadcastChunk(true);
 }
 
-void NodeQueryEngine::run(ServerHandler *server,VNode* root)
+void NodeQueryEngine::run(ServerHandler*,VNode* root)
 {
     runRecursively(root);
 }
@@ -329,10 +329,7 @@ void NodeQueryEngine::slotFailed()
 
 NodeFilterEngine::NodeFilterEngine(NodeFilter* owner) :
     query_(new NodeQuery("tmp")),
-    parser_(nullptr),
-    server_(nullptr),
-    owner_(owner),
-    rootNode_(nullptr)
+    owner_(owner)
 {
 }
 
