@@ -39,7 +39,7 @@ NodeQuery* NodeQueryHandler::add(const std::string& name)
 	return item;
 }
 
-NodeQuery* NodeQueryHandler::add(const std::string& name,const std::string& query)
+NodeQuery* NodeQueryHandler::add(const std::string& name,const std::string& /*query*/)
 {
 	auto *item=new NodeQuery(name);
 	items_.push_back(item);
@@ -95,7 +95,7 @@ void NodeQueryHandler::init(const std::string& dirPath)
 	std::string pattern=".*\\." + suffix_ + "$";
 	DirectoryHandler::findFiles(dirPath_,pattern,res);
 
-	for(std::vector<std::string>::const_iterator it=res.begin(); it != res.end(); ++it)
+	for(auto it=res.begin(); it != res.end(); ++it)
 	{
 		std::string fName=DirectoryHandler::concatenate(dirPath_,*it);
 		VSettings vs(fName);
