@@ -145,10 +145,10 @@ VInfo_ptr NodeQueryResultView::currentSelection()
 	{
 		return model_->nodeInfo(sortModel_->mapToSource(lst.front()));
 	}
-	return VInfo_ptr();
+	return {};
 }
 
-void NodeQueryResultView::currentSelection(VInfo_ptr info)
+void NodeQueryResultView::currentSelection(VInfo_ptr /*info*/)
 {
 	/*QModelIndex idx=model_->infoToIndex(info);
 	if(idx.isValid())
@@ -158,7 +158,7 @@ void NodeQueryResultView::currentSelection(VInfo_ptr info)
 	}*/
 }
 
-void NodeQueryResultView::slotSetCurrent(VInfo_ptr info)
+void NodeQueryResultView::slotSetCurrent(VInfo_ptr /*info*/)
 {
 	/*QModelIndex idx=model_->infoToIndex(info);
 	if(idx.isValid())
@@ -208,7 +208,7 @@ void NodeQueryResultView::slotContextMenu(const QPoint &position)
 }
 
 
-void NodeQueryResultView::handleContextMenu(QModelIndex indexClicked,QModelIndexList indexLst,QPoint globalPos,QPoint widgetPos,QWidget *widget)
+void NodeQueryResultView::handleContextMenu(QModelIndex indexClicked,QModelIndexList indexLst,QPoint globalPos,QPoint /*widgetPos*/,QWidget */*widget*/)
 {
   	//Node actions
   	if(indexClicked.isValid())   //indexLst[0].isValid() && indexLst[0].column() == 0)
@@ -245,7 +245,7 @@ void NodeQueryResultView::slotCommandShortcut()
     }
 }
 
-void NodeQueryResultView::slotViewCommand(std::vector<VInfo_ptr> nodeLst,QString cmd)
+void NodeQueryResultView::slotViewCommand(std::vector<VInfo_ptr> nodeLst,QString /*cmd*/)
 {
 
 	if(nodeLst.size() == 0)
