@@ -57,7 +57,7 @@ struct QueryAttrDelegateBox : public AttrDelegateBox
       }
 };
 
-NodeQueryViewDelegate::NodeQueryViewDelegate(QWidget *parent)
+NodeQueryViewDelegate::NodeQueryViewDelegate(QWidget */*parent*/)
 {
     nodeBox_=new QueryNodeDelegateBox;
     attrBox_=new QueryAttrDelegateBox;
@@ -78,13 +78,13 @@ NodeQueryViewDelegate::NodeQueryViewDelegate(QWidget *parent)
 
     prop_=new PropertyMapper(propVec,this);
 
-    updateSettings();
+    updateSettingsInternal();
 }
 
 NodeQueryViewDelegate::~NodeQueryViewDelegate()
 = default;
 
-void NodeQueryViewDelegate::updateSettings()
+void NodeQueryViewDelegate::updateSettingsInternal()
 {
     //Update the settings handled by the base class
     updateBaseSettings();
@@ -239,7 +239,7 @@ void NodeQueryViewDelegate::renderNode(QPainter *painter,const QModelIndex& inde
 	}
 
 	//Draw text
-	QColor fg=index.data(Qt::ForegroundRole).value<QColor>();
+	auto fg=index.data(Qt::ForegroundRole).value<QColor>();
 	painter->setPen(fg);
     painter->drawText(textRect,Qt::AlignHCenter | Qt::AlignVCenter,text);
 
