@@ -35,12 +35,14 @@ public:
                    const QModelIndex& index) const override;
 
 protected:
-    void updateSettings() override;
+    void updateSettings() override {updateSettingsInternal();}
 
     void renderNode(QPainter *painter,const QModelIndex& index,
                                         const QStyleOptionViewItem& option,QString text) const;
+private:
+    void updateSettingsInternal();
 
-    ModelColumn* columns_;
+    ModelColumn* columns_{nullptr};
     QPen borderPen_;
 
 };
