@@ -12,6 +12,8 @@
 #include "OutputBrowser.hpp"
 
 #include <QtGlobal>
+#include <QByteArray>
+#include <QObject>
 #include <QProcess>
 #include <QVBoxLayout>
 
@@ -38,6 +40,98 @@ int OutputBrowser::minPagerTextSize_=40*1024*1024;
 int OutputBrowser::minPagerSparseSize_=40*1024*1024;
 int OutputBrowser::minConfirmSearchSize_=20*1024*1024;
 
+#define UI_OUTPUTBROSWER_DEBUG_
+
+//========================================
+//
+// OutputBrowserState
+//
+//========================================
+
+class OutputBrowserState : public QObject
+{
+public:
+    OutputBrowserState(OutputBrowser* browser) : QObject(browser), browser_(browser) {}
+    ~OutputBrowserState() override = default;
+
+    virtual void handleClear();
+    virtual void handleLoad(VFile_ptr);
+    virtual void handleReloadBegin();
+
+protected:
+    OutputBrowser* browser_{nullptr};
+};
+
+class OutputBrowserEmptyState : public OutputBrowserState
+{
+public:
+    OutputBrowserEmptyState(OutputBrowser* browser);
+    void handleClear() override;
+};
+
+class OutputBrowserNormalState : public OutputBrowserState
+{
+public:
+    using OutputBrowserState::OutputBrowserState;
+};
+
+class OutputBrowserReloadState : public OutputBrowserState
+{
+public:
+    using OutputBrowserState::OutputBrowserState;
+    void handleLoad(VFile_ptr) override;
+};
+
+void OutputBrowserState::handleClear()
+{
+    browser_->transitionTo(new OutputBrowserEmptyState(browser_));
+}
+
+void OutputBrowserState::handleLoad(VFile_ptr file)
+{
+    browser_->clearIt();
+    browser_->loadIt(file);
+    if (browser_->isFileLoaded()) {
+        browser_->transitionTo(new OutputBrowserNormalState(browser_));
+    } else {
+        browser_->transitionTo(new OutputBrowserEmptyState(browser_));
+    }
+}
+
+void OutputBrowserState::handleReloadBegin()
+{
+    browser_->transitionTo(new OutputBrowserReloadState(browser_));
+}
+
+// Empty
+OutputBrowserEmptyState::OutputBrowserEmptyState(OutputBrowser* b) :
+    OutputBrowserState(b)
+{
+    browser_->clearIt();
+}
+
+void OutputBrowserEmptyState::handleClear()
+{
+    browser_->clearIt();
+}
+
+// Reload
+void OutputBrowserReloadState::handleLoad(VFile_ptr file)
+{
+    browser_->reloadIt(file);
+    if (browser_->isFileLoaded()) {
+        browser_->transitionTo(new OutputBrowserNormalState(browser_));
+    } else {
+        browser_->transitionTo(new OutputBrowserEmptyState(browser_));
+    }
+}
+
+//========================================
+//
+// OutputBrowser
+//
+//========================================
+
 OutputBrowser::OutputBrowser(QWidget* parent) :
     QWidget(parent),
     searchTb_(nullptr)
@@ -107,6 +201,9 @@ OutputBrowser::OutputBrowser(QWidget* parent) :
 
     //the textfilter is is hidden by default
     textFilter_->hide();
+
+    // initialise state
+    transitionTo(new OutputBrowserEmptyState(this));
 }
 
 OutputBrowser::~OutputBrowser()
@@ -130,112 +227,116 @@ void OutputBrowser::setFilterButtons(QToolButton* statusTb,QToolButton* optionTb
     textFilter_->setExternalButtons(statusTb,optionTb);
 }
 
+//--------------------
+// Public interface
+//--------------------
 void OutputBrowser::clear()
 {
-    textEdit_->clear();
-    textPager_->clear();
-    htmlEdit_->clear();
-    file_.reset();
-    oriFile_.reset();
-}
-
-void OutputBrowser::changeIndex(IndexType indexType,qint64 fileSize)
-{
-    if(indexType == BasicIndex)
-    {
-        stacked_->setCurrentIndex(indexType);               
-        textPager_->clear();
-        htmlEdit_->clear();
-
-        //enable and init search
-        if(searchTb_) searchTb_->setEnabled(true);
-        searchLine_->setConfirmSearch(fileSize >=minConfirmSearchSize_);
-        searchLine_->setSearchInterface(textEditSearchInterface_);
-
-        //enable filter
-        textFilter_->setEnabledExternalButtons(true);
-    }
-    else if(indexType == PagerIndex)
-    {
-        stacked_->setCurrentIndex(indexType);          
-        textEdit_->clear();
-        htmlEdit_->clear();
-
-        //enable and init search
-        if(searchTb_) searchTb_->setEnabled(true);
-        searchLine_->setConfirmSearch(fileSize >=minConfirmSearchSize_);
-        searchLine_->setSearchInterface(textPagerSearchInterface_);
-
-        //enable filter
-        textFilter_->setEnabledExternalButtons(true);
-    }
-    else if(indexType == HtmlIndex)
-    {
-        stacked_->setCurrentIndex(indexType);
-        textPager_->clear();
-        textEdit_->clear();
-        if(oriFile_)
-            oriFile_.reset();
-
-        //Disable search
-        if(searchTb_) searchTb_->setEnabled(false);
-        searchLine_->setSearchInterface(nullptr);
-        searchLine_->hide();
-
-        //Disable filter
-        textFilter_->closeIt();
-        textFilter_->setEnabledExternalButtons(false);
-    }
-
-    showConfirmSearchLabel();
-    Q_EMIT wordWrapSupportChanged(isWordWrapSupported());
+    state_->handleClear();
 }
 
 //This should only be called externally when a new output is loaded
 void OutputBrowser::loadFile(VFile_ptr file)
 {
-    if(!file)
-    {
-        clear();
+    state_->handleLoad(file);
+}
+
+void OutputBrowser::reloadBegin()
+{
+    state_->handleReloadBegin();
+}
+
+//---------------------------
+// Internal implementations
+//---------------------------
+void OutputBrowser::clearIt()
+{
+    textEdit_->clear();
+    textPager_->clear();
+    htmlEdit_->clear();
+    file_.reset();
+    contentsFile_.reset();
+    lastLoadedSizeFromDisk_=0;
+}
+
+void OutputBrowser::loadIt(VFile_ptr file)
+{
+    contentsChangedOnLastLoad_ = true;
+    lastLoadedSizeFromDisk_=0;
+
+    file_ = file;
+    if(!file_) {
+        return;
+    }
+    Q_ASSERT(!file->hasDeltaContents());
+    contentsFile_ = filterIt();
+
+    loadContents(file_->fetchMode() == VFile::LocalFetchMode);
+}
+
+void OutputBrowser::reloadIt(VFile_ptr file)
+{
+    contentsChangedOnLastLoad_ = false;
+
+    if(!file) {
+        clearIt();
         return;
     }
 
-    file_=file;
-    if(file_->storageMode() == VFile::DiskStorage)
-    {
-        loadFile(QString::fromStdString(file_->path()));
-    }
-    else
-    {
-        QString s(file_->data());
-        loadText(s,QString::fromStdString(file_->sourcePath()),file_->dataSize(), true);
+    // Local cannot have deltacontents. We want to avoid recursion!
+    bool local = (file_ && file_->fetchMode() == VFile::LocalFetchMode && file->fetchMode() == VFile::LocalFetchMode);
+    VFile_ptr delta;
+
+    if (local) {
+        file_=file;
+    } else if (file->hasDeltaContents() && file_) {
+        assert(file->fetchMode() != VFile::LocalFetchMode);
+        delta = file;
+        if (!file_->append(file)) {
+            return;
+        }
+    } else {
+        file_=file;
     }
 
-    //Run the filter if defined
-    if(textFilter_->isActive())
-    {
-        slotRunFilter(textFilter_->filterText(),textFilter_->isMatched(),
-                      textFilter_->isCaseSensitive());
+    //TODO: this is not neccesarily true when a local file is updated since at this point we do not know if
+    // the file changed
+    contentsChangedOnLastLoad_ = true;
+    contentsFile_ = filterIt();
+    bool contentsSame = contentsFile_.get() == file_.get();
+
+    bool deltaAdded = false;
+    if (delta && contentsFile_.get() == file_.get()) {
+        deltaAdded = addDeltaContents(delta);
+    }
+    if(!deltaAdded) {
+        loadContents(contentsSame && local);
     }
 }
 
-void OutputBrowser::loadFilteredFile(VFile_ptr file)
+void OutputBrowser::loadContents(bool manageLocal)
 {
-    if(!file)
-    {
-        clear();
+    if (contentsFile_ && file_) {
+        if(contentsFile_->storageMode() == VFile::DiskStorage)
+        {
+            loadContentsFromDisk(QString::fromStdString(contentsFile_->path()), QString::fromStdString(file_->path()), manageLocal);
+        }
+        else
+        {
+            QString s(contentsFile_->data());
+            loadContentsFromText(s,QString::fromStdString(file_->sourcePath()),contentsFile_->dataSize(), true);
+        }
+    }
+}
+
+void OutputBrowser::loadContentsFromDisk(QString contentsFileName, QString fileName, bool manageLocal)
+{
+    QFile file(contentsFileName);
+    if (!file.open(QIODevice::ReadOnly)) {
+        lastLoadedSizeFromDisk_ = 0;
         return;
     }
 
-    file_=file;
-    Q_ASSERT(file_->storageMode() == VFile::DiskStorage);
-    loadFile(QString::fromStdString(file_->path()));
-}
-
-void OutputBrowser::loadFile(QString fileName)
-{
-    QFile file(fileName);
-    file.open(QIODevice::ReadOnly);
     QFileInfo fInfo(file);
     qint64 fSize=fInfo.size();
 
@@ -250,28 +351,57 @@ void OutputBrowser::loadFile(QString fileName)
 #if QT_VERSION >= QT_VERSION_CHECK(5, 0, 0)
         QGuiApplication::restoreOverrideCursor();
 #endif
-
     }
     else if(!isJobFile(fileName) && fSize >= minPagerTextSize_)
     {
         changeIndex(PagerIndex,fSize);
-
         TextPagerDocument::DeviceMode mode=(fSize >= minPagerSparseSize_)?
         		           TextPagerDocument::Sparse:TextPagerDocument::LoadAll;
-        textPager_->load(fileName, mode);
+        textPager_->load(contentsFileName, mode);
+        lastLoadedSizeFromDisk_ = 0;
     }
     else
     {
     	changeIndex(BasicIndex,fSize);
-
         adjustHighlighter(fileName);
-       
-        QString str=file.readAll();
-        textEdit_->document()->setPlainText(str);
+               
+        bool loaded = false;
+        if (manageLocal && !isJobFile(fileName) && lastLoadedSizeFromDisk_ > 0) {
+           if (lastLoadedSizeFromDisk_ < fSize) {
+#ifdef UI_OUTPUTBROSWER_DEBUG_
+                UiLog().dbg() << UI_FN_INFO << "load local file from offset=" << lastLoadedSizeFromDisk_;
+#endif
+                if (file.seek(lastLoadedSizeFromDisk_)) {
+                    QByteArray arr = file.readAll();
+                    lastLoadedSizeFromDisk_ += arr.size();
+                    QString deltaTxt(arr);
+                    // appendPlainText always inserts a newline so we cannot use it here
+                    QTextCursor cursor = QTextCursor(textEdit_->document());
+                    cursor.movePosition(QTextCursor::End);
+                    cursor.insertText(deltaTxt);
+                    loaded = true;
+                }
+            } else if (lastLoadedSizeFromDisk_ == fSize) {
+#ifdef UI_OUTPUTBROSWER_DEBUG_
+                UiLog().dbg() << UI_FN_INFO << "no need to load: local file is the same";
+                loaded = true;
+#endif
+           }
+        }
+
+        if(!loaded) {
+            QByteArray arr = file.readAll();
+            if (manageLocal) {
+                lastLoadedSizeFromDisk_ = arr.size();
+            }
+            QString str(arr);
+            UiLog().dbg() << UI_FN_INFO << "load whole file";
+            textEdit_->document()->setPlainText(str);
+        }
     }
 }
 
-void OutputBrowser::loadText(QString txt,QString fileName, size_t dataSize, bool resetFile)
+void OutputBrowser::loadContentsFromText(QString txt,QString fileName, size_t dataSize, bool /*resetFile*/)
 {
     // prior to the ability to save local copies of files, we reset the file_ member here;
     // but now we need to keep it so that we can save a copy of it
@@ -307,6 +437,75 @@ void OutputBrowser::loadText(QString txt,QString fileName, size_t dataSize, bool
     //updateCursorFromCache(fileName.toStdString());
 }
 
+// try to add delta contents, not all the modes support it so the return value indicates
+// if it was possible
+bool OutputBrowser::addDeltaContents(VFile_ptr delta)
+{
+    if (delta && contentsFile_ && file_) {
+        if(delta->storageMode() == VFile::DiskStorage)
+        {
+            return addDeltaContentsFromDisk(QString::fromStdString(delta->path()), QString::fromStdString(file_->path()),
+                                            file_->sizeInBytes());
+        }
+        else
+        {
+            QString s(delta->data());
+            return addDeltaContentsFromText(s,QString::fromStdString(file_->sourcePath()),
+                                            file_->sizeInBytes());
+        }
+    }
+    return false;
+}
+
+
+bool OutputBrowser::addDeltaContentsFromDisk(QString deltaFileName, QString fileName, size_t fileSize)
+{
+    if(isHtmlFile(fileName)) {
+       return false;
+    }
+    else if(!isJobFile(fileName) || fileSize <= static_cast<size_t>(minPagerTextSize_)) {
+        changeIndex(BasicIndex,fileSize);
+        adjustHighlighter(fileName);
+#ifdef UI_OUTPUTBROSWER_DEBUG_
+        UiLog().dbg() << UI_FN_INFO << " deltaFileName=" << deltaFileName;
+#endif
+        QFile file(deltaFileName);
+        if (file.open(QIODevice::ReadOnly)) {
+            QString deltaTxt=file.readAll();
+            // appendPlainText always inserts a newline so we cannot use it here
+            QTextCursor cursor = QTextCursor(textEdit_->document());
+            cursor.movePosition(QTextCursor::End);
+            cursor.insertText(deltaTxt);
+            return true;
+        } else {
+            return false;
+        }
+    }
+    return false;
+}
+
+bool OutputBrowser::addDeltaContentsFromText(QString deltaTxt,QString fileName, size_t fileSize)
+{
+    // at this point file_ has already been updated with the delta and fileSize contains the
+    // new size. It is guaranteed_ that file_ == contentsFile_
+    if(isHtmlFile(fileName)) {
+        return false;
+    } if (isJobFile(fileName) || fileSize <= static_cast<size_t>(minPagerTextSize_)) {
+#ifdef UI_OUTPUTBROSWER_DEBUG_
+        UiLog().dbg() << UI_FN_INFO << " text_size=" << deltaTxt.size();
+#endif
+        changeIndex(BasicIndex,fileSize);
+        adjustHighlighter(fileName);
+        // appendPlainText always inserts a newline so we cannot use it here
+        QTextCursor cursor = QTextCursor(textEdit_->document());
+        cursor.movePosition(QTextCursor::End);
+        cursor.insertText(deltaTxt);
+
+        return true;
+    }
+    return false;
+}
+
 void OutputBrowser::saveCurrentFile(QString &fileNameToSaveTo)
 {
     assert(file_);
@@ -339,6 +538,60 @@ void OutputBrowser::saveCurrentFile(QString &fileNameToSaveTo)
     }
 }
 
+
+void OutputBrowser::changeIndex(IndexType indexType,qint64 fileSize)
+{
+    if(indexType == BasicIndex)
+    {
+        stacked_->setCurrentIndex(indexType);
+        textPager_->clear();
+        htmlEdit_->clear();
+
+        //enable and init search
+        if(searchTb_) searchTb_->setEnabled(true);
+        searchLine_->setConfirmSearch(fileSize >=minConfirmSearchSize_);
+        searchLine_->setSearchInterface(textEditSearchInterface_);
+
+        //enable filter
+        textFilter_->setEnabledExternalButtons(true);
+    }
+    else if(indexType == PagerIndex)
+    {
+        stacked_->setCurrentIndex(indexType);
+        textEdit_->clear();
+        htmlEdit_->clear();
+
+        //enable and init search
+        if(searchTb_) searchTb_->setEnabled(true);
+        searchLine_->setConfirmSearch(fileSize >=minConfirmSearchSize_);
+        searchLine_->setSearchInterface(textPagerSearchInterface_);
+
+        //enable filter
+        textFilter_->setEnabledExternalButtons(true);
+    }
+    else if(indexType == HtmlIndex)
+    {
+        stacked_->setCurrentIndex(indexType);
+        textPager_->clear();
+        textEdit_->clear();
+
+        // the filtered contents should be released
+        contentsFile_ = file_;
+
+        //Disable search
+        if(searchTb_) searchTb_->setEnabled(false);
+        searchLine_->setSearchInterface(nullptr);
+        searchLine_->hide();
+
+        //Disable filter
+        textFilter_->closeIt();
+        textFilter_->setEnabledExternalButtons(false);
+    }
+
+    showConfirmSearchLabel();
+    Q_EMIT wordWrapSupportChanged(isWordWrapSupported());
+}
+
 bool OutputBrowser::isFileLoaded()
 {
     return (file_ != nullptr);
@@ -501,20 +754,31 @@ void OutputBrowser::setCursorPos(qint64 pos)
     }
 }
 
-void OutputBrowser::slotRunFilter(QString filter,bool matched,bool caseSensitive)
+void OutputBrowser::slotRunFilter(QString /*filter*/,bool /*matched*/,bool /*caseSensitive*/)
 {
-    if(stacked_->currentIndex() == HtmlIndex)
-        return;
+    contentsFile_ = filterIt();
+    loadContents(false);
+}
 
-    if(!file_)
-        return;
+//Run the filter if defined. If no filtering can be performed the original file is returned.
+VFile_ptr OutputBrowser::filterIt()
+{
+    if (!textFilter_->isActive() || stacked_->currentIndex() == HtmlIndex || !file_) {
+        return file_;
+    }
 
-    if(oriFile_)
-        file_=oriFile_;
+    QString filter = textFilter_->filterText();
+    bool matched = textFilter_->isMatched();
+    bool caseSensitive = textFilter_->isCaseSensitive();
+
+    if (filter.isEmpty()){
+        return file_;
+    }
 
     VFile_ptr fTarget=VFile::createTmpFile(true);
     VFile_ptr fSrc=VFile_ptr();
 
+    Q_ASSERT(file_);
     // file is on disk - we use it as it is
     if(file_->storageMode() == VFile::DiskStorage)
     {
@@ -531,9 +795,6 @@ void OutputBrowser::slotRunFilter(QString filter,bool matched,bool caseSensitive
             QString s(file_->data());
             out << s;
         }
-        else
-        {
-        }
     }
 
     //At this point point fSrc must contain the text to filter
@@ -555,8 +816,10 @@ void OutputBrowser::slotRunFilter(QString filter,bool matched,bool caseSensitive
          QStringList() <<  "-c" << "grep " + extraOptions + " -e \'" + filter  + "\' " +
          QString::fromStdString(fSrc->path()));
 
+#ifdef UI_OUTPUTBROSWER_DEBUG_
 #if QT_VERSION >= QT_VERSION_CHECK(5, 0, 0)
     UiLog().dbg() << "args=" << proc.arguments().join(" ");
+#endif
 #endif
 
     if(!proc.waitForStarted(1000))
@@ -565,7 +828,6 @@ void OutputBrowser::slotRunFilter(QString filter,bool matched,bool caseSensitive
         QGuiApplication::restoreOverrideCursor();
 #endif
         QString errStr;
-        UI_FUNCTION_LOG
 #if QT_VERSION >= QT_VERSION_CHECK(5, 0, 0)
         errStr="Failed to start text filter using command:<br> \'" +
                              proc.program() + " " + proc.arguments().join(" ") + "\'";
@@ -574,7 +836,7 @@ void OutputBrowser::slotRunFilter(QString filter,bool matched,bool caseSensitive
 #endif
         UserMessage::message(UserMessage::ERROR,true,errStr.toStdString());
         fTarget.reset();
-        return;
+        return file_;
     }
 
     proc.waitForFinished(60000);
@@ -586,13 +848,14 @@ void OutputBrowser::slotRunFilter(QString filter,bool matched,bool caseSensitive
     QString errStr=proc.readAllStandardError();
     if(proc.exitStatus() == QProcess::NormalExit && errStr.isEmpty())
     {
-        oriFile_=file_;
+        //oriFile_=file_;
         bool empty = fTarget->isEmpty();
         textFilter_->setStatus(empty?(TextFilterWidget::NotFoundStatus):(TextFilterWidget::FoundStatus));
         if (textFilter_->needNumberOfLines() && !empty) {
            textFilter_->setNumberOfLines(fTarget->numberOfLines());
         }
-        loadFilteredFile(fTarget);
+        return fTarget;
+        //loadFilteredFile(fTarget);
     }
     else
     {        
@@ -612,7 +875,7 @@ void OutputBrowser::slotRunFilter(QString filter,bool matched,bool caseSensitive
         fTarget.reset(); //delete
     }
 
-    return;
+    return file_;
 }
 
 void OutputBrowser::slotRemoveFilter()
@@ -620,9 +883,22 @@ void OutputBrowser::slotRemoveFilter()
     if(stacked_->currentIndex() == HtmlIndex)
         return;
 
-    if(oriFile_)
-    {
-        loadFile(oriFile_);
-        oriFile_.reset();
+    contentsFile_ = file_;
+    loadContents(false);
+}
+
+size_t OutputBrowser::sizeInBytes() const
+{
+    return (file_)?file_->sizeInBytes():0;
+}
+
+void OutputBrowser::transitionTo(OutputBrowserState* state)
+{
+#ifdef MVQFEATURESELECTORITEM_DEBUG_
+    std::cout << " MvQFeatureSelectorItem::transitionTo " << typeid(*state).name() << "\n";
+#endif
+    if (state_ != nullptr) {
+        state_->deleteLater();
     }
+    state_ = state;
 }
