@@ -9,8 +9,10 @@
 
 #include "OutputClient.hpp"
 
+#include <QtGlobal>
 #include <QNetworkProxy>
 #include <QTimer>
+#include "UiLog.hpp"
 
 OutputClient::OutputClient(const std::string& host,const std::string& portStr,QObject* parent) :
 	QObject(parent),
@@ -18,7 +20,7 @@ OutputClient::OutputClient(const std::string& host,const std::string& portStr,QO
 	host_(host),
 	portStr_(portStr),
 	port_(19999),
-	timeout_(3000)
+    timeout_(3000)
 {
 	if(!portStr_.empty())
 		port_=atoi(portStr.c_str());
@@ -30,7 +32,11 @@ OutputClient::OutputClient(const std::string& host,const std::string& portStr,QO
 	connect(soc_,SIGNAL(readyRead()),
 		  this, SLOT(slotRead()));
 
-	connect(soc_,SIGNAL(error(QAbstractSocket::SocketError)),
+#if QT_VERSION >= QT_VERSION_CHECK(5, 15, 0)
+    connect(soc_,SIGNAL(errorOccurred(QAbstractSocket::SocketError)),
+#else
+    connect(soc_,SIGNAL(error(QAbstractSocket::SocketError)),
+#endif
 			this,SLOT(slotError(QAbstractSocket::SocketError)));
 
 	connect(soc_,SIGNAL(connected()),
@@ -45,13 +51,16 @@ OutputClient::~OutputClient()
 	soc_->abort();
 }
 
-
 void OutputClient::connectToHost(std::string host,int port)
 {
 	stopper_.start();
 	soc_->abort();
-	soc_->connectToHost(QString::fromStdString(host),port);
-
+    if (host != "localhost") {
+        soc_->connectToHost(QString::fromStdString(host),port);
+    } else {
+        // On macOS using the string "localhost" did not work
+        soc_->connectToHost(QHostAddress::LocalHost, port);
+    }
     //We cannot change the timeout through the qt api so we need this hack.
 	QTimer::singleShot(timeout_, this, SLOT(slotCheckTimeout()));
 }
@@ -62,6 +71,12 @@ void OutputClient::slotCheckTimeout()
 	   soc_->state() == QAbstractSocket::ConnectingState)
 	{
 		soc_->abort();
+        timeoutError();
 		Q_EMIT error("Timeout error");
 	}
 }
+
+std::string OutputClient::longName() const
+{
+     return host_ + "@" + portStr_;
+}
