@@ -43,9 +43,10 @@ void OutputDirClient::slotCheckTimeout()
 
 void OutputDirClient::slotConnected()
 {
+#ifdef _UI_OUTPUTDIRCLIENT_DEBUG
     UiLog().dbg() << "OutputDirClient::slotConnected() connected to " <<
                          soc_->peerName();
-
+#endif
 	soc_->write("list ",5);
 	soc_->write(remoteFile_.c_str(),remoteFile_.size());
 	soc_->write("\n",1);
@@ -112,8 +113,6 @@ void OutputDirClient::slotError(QAbstractSocket::SocketError err)
 
 void OutputDirClient::getDir(const std::string& name)
 {
-	connectToHost(host_,port_);
-
 	boost::filesystem::path fp(name);
 	std::string dirName=fp.parent_path().string();
 
@@ -124,6 +123,8 @@ void OutputDirClient::getDir(const std::string& name)
 
 	//indicates the source of the files
 	dir_->where(host_ + "@" + portStr_);
+
+    connectToHost(host_,port_);
 }
 
 void OutputDirClient::slotRead()
@@ -146,9 +147,9 @@ void OutputDirClient::parseData()
 	QTextStream in(data_);
 	while(!in.atEnd())
 	{
-		 int mode,uid,gid;
-		 unsigned int size;
-		 unsigned int atime,mtime,ctime;
+		 int mode = 0,uid = 0,gid = 0;
+		 unsigned int size = 0;
+		 unsigned int atime = 0,mtime = 0,ctime = 0;
 		 QString name;
 
 		 in >> mode >> uid >> gid >> size >> atime >> mtime >> ctime >> name;
