@@ -29,7 +29,7 @@ OutputModel::OutputModel(QObject *parent) :
 {
 }
 
-void OutputModel::setData(const std::vector<VDir_ptr>& dirs,const std::string& jobout)
+void OutputModel::resetData(const std::vector<VDir_ptr>& dirs,const std::string& jobout)
 {
     beginResetModel();
     dirs_=dirs;
@@ -86,14 +86,14 @@ QVariant  OutputModel::data(const QModelIndex& index, int role) const
 {
     if(!hasData() || (role != Qt::DisplayRole && role != Qt::UserRole &&
         role != Qt::ForegroundRole && role != Qt::ToolTipRole && role != Qt::FontRole))
-		return QVariant();
+		return {};
 
 	int row=index.row();
     VDir_ptr dir;
     VDirItem *item=itemAt(row,dir);
 
     if(!item || !dir)
-        return QVariant();
+        return {};
 
     if(role == Qt::DisplayRole)
     {
@@ -165,7 +165,7 @@ QVariant  OutputModel::data(const QModelIndex& index, int role) const
     }
 
 
-	return QVariant();
+	return {};
 }
 
 QVariant OutputModel::headerData( const int section, const Qt::Orientation orient , const int role ) const
@@ -181,10 +181,10 @@ QVariant OutputModel::headerData( const int section, const Qt::Orientation orien
     case 3: return tr("Modified (ago)");
     case 4: return tr("Modified");
     case 5: return tr("Source");
-   	default: return QVariant();
+   	default: return {};
     }
 
-    return QVariant();
+    return {};
 }
 
 QModelIndex OutputModel::index( int row, int column, const QModelIndex & parent ) const
@@ -243,7 +243,7 @@ bool OutputModel::hasData() const
 std::string OutputModel::fullName(const QModelIndex& index) const
 {
 	if(!hasData())
-		return std::string();
+		return {};
 
     int row=index.row();
     for(const auto & dir : dirs_)
@@ -260,7 +260,7 @@ std::string OutputModel::fullName(const QModelIndex& index) const
        }
     }
 
-    return std::string();
+    return {};
 }
 
 void OutputModel::itemDesc(const QModelIndex& index,std::string& itemFullName,VDir::FetchMode& mode) const
@@ -290,7 +290,7 @@ void OutputModel::itemDesc(const QModelIndex& index,std::string& itemFullName,VD
 
 QModelIndex OutputModel::itemToIndex(const std::string& itemFullName,VDir::FetchMode fetchMode) const
 {
-    int row=0;;
+    int row=0;
     for(const auto & dir : dirs_)
     {
         if(dir)
@@ -308,6 +308,18 @@ QModelIndex OutputModel::itemToIndex(const std::string& itemFullName,VDir::Fetch
     return {};
 }
 
+QModelIndex OutputModel::itemToIndex(const std::string& itemFullName) const
+{
+    int row=0;
+    for(const auto & dir : dirs_) {
+        if(dir) {
+            for(int j=0; j < dir->count(); j++, row++)
+                if(dir->fullName(j) == itemFullName)
+                    return index(row,0);
+        }
+    }
+    return {};
+}
 
 QString OutputModel::formatSize(unsigned int size) const
 {
@@ -318,9 +330,9 @@ QString OutputModel::formatSize(unsigned int size) const
 	else if(size < 1024*1024*1024)
 	  	return QString::number(size/(1024*1024)) + " MB";
 	else
-	  	return QString::number(size/(1024*1024*1024)) + " GB";
+        return QString::number(static_cast<float>(size)/(1024.*1024.*1024.), 'f', 1) + " GB";
 
- 	return QString();
+ 	return {};
 }
 
 QString OutputModel::formatDate(QDateTime dt) const
@@ -408,11 +420,11 @@ QModelIndex OutputSortModel::fullNameToIndex(const std::string& fullName)
 //
 //========================================================
 
-OutputDirLitsDelegate::OutputDirLitsDelegate(QWidget *parent) : QStyledItemDelegate(parent)
+OutputDirListDelegate::OutputDirListDelegate(QWidget *parent) : QStyledItemDelegate(parent)
 {
 }
 
-void OutputDirLitsDelegate::paint(QPainter *painter,const QStyleOptionViewItem &option,
+void OutputDirListDelegate::paint(QPainter *painter,const QStyleOptionViewItem &option,
                    const QModelIndex& index) const
 {
     if(index.column()==1)
