@@ -10,6 +10,8 @@
 
 #include "PropertyEditor.hpp"
 
+#include <cstdlib>
+
 #include <QDebug>
 #include <QGroupBox>
 #include <QFrame>
@@ -94,7 +96,7 @@ void PropertyEditor::build()
 	if(!group_)
 		return;
 
-	assert(holder_==NULL);
+	assert(holder_==nullptr);
 
 	holder_=new QWidget(scAreaContents_);
     holder_->setObjectName("h");
@@ -438,7 +440,7 @@ void PropertyEditor::addNotification(VProperty* vProp,QVBoxLayout* layout,QWidge
 
     		QList<PropertyLine*> lineLst;
 
-    		QWidget* w=new QWidget(parent);
+    		auto* w=new QWidget(parent);
     		auto* vb=new QVBoxLayout(w);
     		//vb->setContentsMargins(4,4,4,4);
 
@@ -446,7 +448,7 @@ void PropertyEditor::addNotification(VProperty* vProp,QVBoxLayout* layout,QWidge
             
             if(VProperty *root=VConfig::instance()->find(chProp->param("root").toStdString()))
             {
-            	QLabel *labelDesc=new QLabel(tr("Description: <b>") + root->param("description") + "</b>",w);
+            	auto *labelDesc=new QLabel(tr("Description: <b>") + root->param("description") + "</b>",w);
             	//labelDesc->setProperty("editorNotifyHeader","1");
             	vb->addWidget(labelDesc);
             	vb->addSpacing(5);
@@ -513,6 +515,10 @@ void PropertyEditor::addTabs(VProperty* vProp,QVBoxLayout *layout,QWidget* paren
     auto *t=new QTabWidget(parent);
     t->setObjectName("tab");
     layout->addWidget(t);
+
+    if (!topLevelTabW_  && parent == holder_) {
+        topLevelTabW_ = t;
+    }
    
     Q_FOREACH(VProperty* chProp,vProp->children())
     {
@@ -534,7 +540,6 @@ void PropertyEditor::addTab(VProperty* vProp,QTabWidget* tab)
     
     tab->addTab(w,vProp->param("label"));
     
-
     if(!vProp->param("adjustLineLabel").isEmpty())
     {
         lineLabelLen_=vProp->param("adjustLineLabel").toInt();
@@ -550,13 +555,19 @@ void PropertyEditor::addTab(VProperty* vProp,QTabWidget* tab)
     vb->addStretch(1);
 }    
 
+QString PropertyEditor::buildNoteText(VProperty* vProp) const
+{
+    QString txt=vProp->value().toString();
+    txt.replace("%SERVER%",(serverName_.isEmpty())?"?":"<b>" + serverName_ + "</b>");
+    return txt;
+}
+
 void PropertyEditor::addNote(VProperty* vProp,QVBoxLayout* layout,QWidget *parent)
 {
     if(vProp->name() != "note")
         return;
 
-    QString txt=vProp->value().toString();
-    txt.replace("%SERVER%",(serverName_.isEmpty())?"?":"<b>" + serverName_ + "</b>");
+    QString txt=buildNoteText(vProp);
 
     layout->addSpacing(5);
     auto *label=new QLabel("<i>Note:</i> " + txt,parent);
@@ -568,23 +579,13 @@ void PropertyEditor::addNote(VProperty* vProp,QGridLayout* layout,QWidget *paren
     if(vProp->name() != "note")
         return;
 
-    QString txt=vProp->value().toString();
-    txt.replace("%SERVER%",(serverName_.isEmpty())?"?":"<b>" + serverName_ + "</b>");
-
-    //QLabel *empty=new QLabel(" ",parent);
-    //layout->addWidget(empty,layout->rowCount(),0,1,-1,Qt::AlignVCenter);
-   	//QLabel *label=new QLabel("&nbsp;&nbsp;&nbsp;<b>Note:</b> " + txt,parent);
-
-    //QFrame* fr=new QFrame(parent);
-    //fr->setFrameShape(QFrame::HLine);
-    //layout->addWidget(fr,layout->rowCount(),0,1,-1,Qt::AlignVCenter);
+    QString txt=buildNoteText(vProp);
 
     auto *label=new QLabel("<table><tr><td><b>&nbsp;&nbsp;&nbsp;</b></td><td><i>Note:</i> " + txt + "</td></tr></table>",parent);
     label->setWordWrap(true);
     layout->addWidget(label,layout->rowCount(),0,1,-1,Qt::AlignVCenter);
 }
 
-
 bool PropertyEditor::applyChange()
 {
     bool changed=false;
@@ -601,3 +602,14 @@ bool PropertyEditor::applyChange()
     return changed;
 }
 
+int PropertyEditor::currentTopLevelTabIndex() const
+{
+    return (topLevelTabW_)?topLevelTabW_->currentIndex():-1;
+}
+
+void PropertyEditor::setCurrentTopLevelTabIndex(int idx)
+{
+    if (topLevelTabW_) {
+        topLevelTabW_->setCurrentIndex(idx);
+    }
+}
