@@ -1,5 +1,5 @@
 //============================================================================
-// Copyright 2009-2020 ECMWF.
+// Copyright 2009- ECMWF.
 // This software is licensed under the terms of the Apache Licence version 2.0
 // which can be obtained at http://www.apache.org/licenses/LICENSE-2.0.
 // In applying this licence, ECMWF does not waive the privileges and immunities
@@ -16,7 +16,7 @@
 #include "VTask.hpp"
 
 #include <QObject>
-#include <QTime>
+#include <QElapsedTimer>
 #include <QTimer>
 
 class ClientInvoker;
@@ -80,7 +80,7 @@ protected:
 	ServerComThread *comThread_;
 	QTimer* timer_;
     int timeout_;
-    QTime ctStartTime_;
+    QElapsedTimer ctStartTime_;
     int ctStartTimeout_;
     int ctStartWaitTimeout_;
     int startTimeoutTryCnt_;
