@@ -26,12 +26,7 @@
 
 ServerComThread::ServerComThread(ServerHandler *server, ClientInvoker *ci) :
         server_(server),
-        ci_(ci),
-        taskType_(VTask::NoTask),
-        rescanNeed_(false),
-        hasSuiteFilter_(false),
-        autoAddNewSuites_(false),
-        maxLineNum_(-1)
+        ci_(ci)
 {
     assert(server_);
 }
@@ -146,7 +141,11 @@ void ServerComThread::run()
                     if(command_.size() >=7 && command_[1] == "--alter" && command_[3] == "variable" &&
                        (command_[2] == "change" || command_[2] == "add"))
                     {
-                        ci_->alter(command_[6],command_[2],command_[3],command_[4],command_[5]);
+                        std::vector<std::string> cmdPaths;
+                        for(size_t i=6; i < command_.size(); i++) {
+                            cmdPaths.emplace_back(command_[i]);
+                        }
+                        ci_->alter(cmdPaths,command_[2],command_[3],command_[4],command_[5]);
                     }
 
                     // call the client invoker with the saved command
@@ -506,7 +505,7 @@ void ServerComThread::update(const Node* node, const std::vector<ecf::Aspect::Ty
 }
 
 
-void ServerComThread::update(const Defs* dc, const std::vector<ecf::Aspect::Type>& types)
+void ServerComThread::update(const Defs* /*dc*/, const std::vector<ecf::Aspect::Type>& types)
 {
     std::vector<ecf::Aspect::Type> typesCopy=types;
 
@@ -604,7 +603,7 @@ void ServerComThread::attach(Node *node)
 
     node->attach(this);
 
-    for(std::vector<node_ptr>::const_iterator it=nodes.begin(); it != nodes.end(); ++it)
+    for(auto it=nodes.begin(); it != nodes.end(); ++it)
     {
         attach((*it).get());
     }
@@ -646,7 +645,7 @@ void ServerComThread::detach(Node *node)
 
     node->detach(this);
 
-    for(std::vector<node_ptr>::const_iterator it=nodes.begin(); it != nodes.end(); ++it)
+    for(auto it=nodes.begin(); it != nodes.end(); ++it)
     {
         detach((*it).get());
     }
