@@ -22,28 +22,53 @@ ServerListSyncWidget::ServerListSyncWidget(QWidget *parent) : QWidget(parent)
     setupUi(this);
 
     title_->setShowTypeTitle(false);
+    errorLabel_->setShowTypeTitle(false);
     browser_->setProperty("log","1");
 
-    //Set the list
-    if(ServerList::instance()->syncDate().isValid())
-    {
-        QColor col(39,49,101);
+    QFont f;
+    QFontMetrics fm(f);
+    typeList_->setFixedWidth(ViewerUtil::textWidth(fm,"Host/port changed (2222)"));
 
-        if(ServerList::instance()->hasSyncChange())
+    reload();
+
+    connect(typeList_,SIGNAL(currentItemChanged(QListWidgetItem*,QListWidgetItem*)),
+            this,SLOT(slotTypeChanged(QListWidgetItem*,QListWidgetItem*)));
+}
+
+ServerListSyncWidget::~ServerListSyncWidget()
+= default;
+
+
+void ServerListSyncWidget::reload()
+{
+    title_->clear();
+    errorLabel_->clear();
+    filesTe_->clear();
+    typeList_->clear();
+    browser_->clear();
+
+    QString  t;
+    auto manager = ServerList::instance()->systemFileManager();
+    if (!manager) {
+        return;
+    }
+
+    //Set the list
+    if(manager->syncDate().isValid())
+    {
+        if(manager->hasSyncChange())
         {
-            QString t="Your copy of the system server list was updated <b>";
-            t+="<font color=\'" + col.name() + "\'> at </font></b>" +
-               ServerList::instance()->syncDate().toString("yyyy-MM-dd HH:mm") +
-                    ". This is the list of changes:";
+            t="Your copy of system server list was updated at " +
+                    manager->syncDate().toString("yyyy-MM-dd HH:mm") +  " and some <u>changes</u> were found.";
 
             title_->showInfo(t);
 
-            const std::vector<ServerListSyncChangeItem*>& items=ServerList::instance()->syncChange();
+            auto items=manager->changedItems();
             int matchCnt=0, addedCnt=0, setCnt=0, unsetCnt=0;
             for(auto item : items)
             {
                 if(item->type() == ServerListSyncChangeItem::MatchChange)
-                   matchCnt++;
+                    matchCnt++;
                 else if(item->type() == ServerListSyncChangeItem::AddedChange)
                     addedCnt++;
                 else if(item->type() == ServerListSyncChangeItem::SetSysChange)
@@ -54,44 +79,36 @@ ServerListSyncWidget::ServerListSyncWidget(QWidget *parent) : QWidget(parent)
 
             if(matchCnt > 0)
             {
-                QListWidgetItem *item=new QListWidgetItem("Host/port changed (" + QString::number(matchCnt) + ")");
+                auto *item=new QListWidgetItem("Host/port changed (" + QString::number(matchCnt) + ")");
                 item->setData(Qt::UserRole,ServerListSyncChangeItem::MatchChange);
                 typeList_->addItem(item);
             }
             if(unsetCnt > 0)
             {
-                QListWidgetItem *item=new QListWidgetItem("Server removed (" + QString::number(unsetCnt) + ")");
+                auto *item=new QListWidgetItem("Server removed (" + QString::number(unsetCnt) + ")");
                 item->setData(Qt::UserRole,ServerListSyncChangeItem::UnsetSysChange);
                 typeList_->addItem(item);
             }
             if(addedCnt > 0)
             {
-                QListWidgetItem *item=new QListWidgetItem("New server (" + QString::number(addedCnt) + ")");
+                auto *item=new QListWidgetItem("New server (" + QString::number(addedCnt) + ")");
                 item->setData(Qt::UserRole,ServerListSyncChangeItem::AddedChange);
                 typeList_->addItem(item);
             }
             if(setCnt > 0)
             {
-                QListWidgetItem *item=new QListWidgetItem("Marked as system (" + QString::number(setCnt) + ")");
+                auto *item=new QListWidgetItem("Marked as system (" + QString::number(setCnt) + ")");
                 item->setData(Qt::UserRole,ServerListSyncChangeItem::SetSysChange);
                 typeList_->addItem(item);
             }
 
-            QFont f;
-            QFontMetrics fm(f);
-            typeList_->setFixedWidth(ViewerUtil::textWidth(fm,"Host/port changed (2222)"));
-
-            connect(typeList_,SIGNAL(currentItemChanged(QListWidgetItem*,QListWidgetItem*)),
-                this,SLOT(slotTypeChanged(QListWidgetItem*,QListWidgetItem*)));
-
             typeList_->setCurrentRow(0);
         }
         else
         {
-            QString t="Your copy of the system server list was updated <b>";
-            t+="<font color=\'" + col.name() + "\'> at </font></b>" +
-                ServerList::instance()->syncDate().toString("yyyy-MM-dd HH:mm") +
-                " but <u>no changes</u> were found.";
+            t="Your copy of the system server list was updated at " +
+                    manager->syncDate().toString("yyyy-MM-dd HH:mm") +
+                    " but <u>no changes</u> were found.";
             title_->showInfo(t);
             typeList_->hide();
             browser_->hide();
@@ -99,22 +116,50 @@ ServerListSyncWidget::ServerListSyncWidget(QWidget *parent) : QWidget(parent)
     }
     else
     {
-        QString t="Your copy of the system server list has not been updated!";
+        t="Your copy of the system server list has not been updated!";
         title_->showInfo(t);
         typeList_->hide();
         browser_->hide();
     }
-}
 
-ServerListSyncWidget::~ServerListSyncWidget()
-= default;
+    t = "List of loaded input files:";
+    if (!manager->fetchedFiles().empty()) {
+        t += "<ul>";
+        for (auto p: manager->fetchedFiles()) {
+            t += "<li>" + QString::fromStdString(p) + "</li>";
+        }
+        t += "</ul>";
+    }
+
+    if (!manager->unfetchedFiles().empty()) {
+        t += "The following input files could not be accessed/loaded:";
+        t += "<ul>";
+        for (auto p: manager->unfetchedFiles()) {
+            t += "<li>" + QString::fromStdString(p) + "</li>";
+        }
+        t += "</ul>";
+
+        errorLabel_->showError("Failed to access/load some system server list files (see the Files tab for details)");
+
+        if (!manager->hasSyncChange()) {
+            tabWidget_->setCurrentIndex(0);
+        }
+    }
+
+    filesTe_->setHtml(t);
+
+}
 
 void ServerListSyncWidget::slotTypeChanged(QListWidgetItem* item,QListWidgetItem*)
 {
     if(!item)
         return;
 
-    const std::vector<ServerListSyncChangeItem*>& items=ServerList::instance()->syncChange();
+    auto manager = ServerList::instance()->systemFileManager();
+    if (!manager) {
+        return;
+    }
+    auto items=manager->changedItems();
     ServerListSyncChangeItem::ChangeType type=
             static_cast<ServerListSyncChangeItem::ChangeType>(item->data(Qt::UserRole).toInt());
 
