@@ -145,7 +145,7 @@ void StandardView::layout(int parentId, bool recursiveExpanding,bool afterIsUnin
 
         //We compute the size of the item. For attributes we delay the width computation until we
         //actually paint them and we set their width to 300.
-        int w,h;
+        int w = 0,h = 0;
         delegate_->sizeHintCompute(currentIndex,w,h);
         item->width=w;
         item->height=h;
@@ -711,7 +711,7 @@ QRect StandardView::visualRect(const QModelIndex &index) const
     if(y >=0)
     {
         //return QRect(viewItems_[vi].x, y, viewItems_[vi].width,rh); //TODO: optimise it
-        return {viewItems_[vi].x-1-translation(), y, viewItems_[vi].width+2,viewItems_[vi].height};
+        return {static_cast<int>(viewItems_[vi].x)-1-translation(), y, static_cast<int>(viewItems_[vi].width)+2,static_cast<int>(viewItems_[vi].height)};
     }
     return {};
 }
