@@ -13,6 +13,8 @@
 
 #include <QHeaderView>
 #include <QTreeView>
+
+#include <cassert>
 #include <set>
 
 #include "NodeViewBase.hpp"
@@ -43,7 +45,7 @@ public:
 	VInfo_ptr currentSelection() override;
     void setCurrentSelection(VInfo_ptr n) override;
 	void selectFirstServer() override {}
-	void setModel(TableNodeSortModel *model);
+    void setTableModel(TableNodeSortModel *model);
 
 	void notifyChange(VProperty* p) override;
 
@@ -88,6 +90,10 @@ protected:
     VInfo_ptr lastSelection_;
     bool setCurrentAfterUpdateIsRunning_;
     bool autoScrollToSelection_;
+
+private:
+    // we enforce the usage of setTableModel()
+    void setModel(QAbstractItemModel *) override {assert(false);}
 };
 
 class TableNodeHeaderButton
