@@ -85,10 +85,10 @@ TableNodeWidget::TableNodeWidget(ServerFilter* serverFilter,bool interactive,QWi
     connect(view_->realWidget(),SIGNAL(headerButtonClicked(QString,QPoint)),
     		filterW_,SLOT(slotHeaderFilter(QString,QPoint)));
 
-    connect(model_->data(),SIGNAL(updateBegin()),
+    connect(model_->getData(),SIGNAL(updateBegin()),
             view_->realWidget(),SLOT(slotUpdateBegin()));
 
-    connect(model_->data(),SIGNAL(updateEnd()),
+    connect(model_->getData(),SIGNAL(updateEnd()),
             view_->realWidget(),SLOT(slotUpdateEnd()));
 
 #if 0
@@ -246,7 +246,7 @@ void TableNodeWidget::writeSettings(VComboSettings* vs)
 
 void TableNodeWidget::readSettings(VComboSettings* vs)
 {
-	std::string type=vs->get<std::string>("type","");
+	auto type=vs->get<std::string>("type","");
 	if(type != type_)
 		return;
 
