@@ -179,7 +179,7 @@ public:
 
     int documentSize;
     enum SaveState { NotSaving, Saving, AbortSave } saveState;
-    enum FindState { NotFinding, Finding, AbortFind } mutable findState;
+    enum FindState { NotFinding, Finding, AbortFind } findState;
     QList<TextPagerSection*> sections;
     QPointer<QIODevice> device;
     bool ownDevice, modified;
@@ -245,7 +245,7 @@ Q_SIGNALS:
 #endif
 
 private:
-    friend class TextPagerSection;
+    friend struct TextPagerSection;
 };
 
 // should not be kept as a member. Invalidated on inserts/removes
