@@ -22,7 +22,7 @@ class TextSectionManager : public QObject
 {
     Q_OBJECT
 public:
-    static TextSectionManager *instance() { static TextSectionManager *inst = new TextSectionManager; return inst; }
+    static TextSectionManager *instance() { static auto *inst = new TextSectionManager; return inst; }
 Q_SIGNALS:
     void sectionFormatChanged(TextPagerSection *section);
     void sectionCursorChanged(TextPagerSection *section);
