@@ -43,19 +43,19 @@ public:
     QModelIndex index (int, int, const QModelIndex& parent = QModelIndex() ) const override;
     QModelIndex parent (const QModelIndex & ) const override;
 
-    void setData(TimelineItem*,unsigned int viewStartDateSec,unsigned int viewEndDateSec,
+    void resetData(TimelineItem*,unsigned int viewStartDateSec,unsigned int viewEndDateSec,
                  unsigned int endDateSec);
     void clearData();
     bool hasData() const;
     void determineRowsInPeriod();
 
 protected:
-    TimelineItem* data_;
-    unsigned int viewStartDateSec_;
-    unsigned int viewEndDateSec_;
-    unsigned int endDateSec_;
-    int firstRowInPeriod_;
-    int lastRowInPeriod_;
+    TimelineItem* data_{nullptr};
+    unsigned int viewStartDateSec_{0};
+    unsigned int viewEndDateSec_{0};
+    unsigned int endDateSec_{0};
+    int firstRowInPeriod_{-1};
+    int lastRowInPeriod_{-1};
 };
 
 
