@@ -77,7 +77,7 @@ TimelineDelegate::TimelineDelegate(TimelineModel *model,QWidget *parent) :
 TimelineDelegate::~TimelineDelegate()
 = default;
 
-void TimelineDelegate::notifyChange(VProperty* p)
+void TimelineDelegate::notifyChange(VProperty*)
 {
     updateSettings();
 }
@@ -86,7 +86,7 @@ void TimelineDelegate::updateSettings()
 {
     if(VProperty* p=prop_->find("view.table.font"))
     {
-        QFont newFont=p->value().value<QFont>();
+        auto newFont=p->value().value<QFont>();
 
         if(font_ != newFont)
         {
@@ -727,7 +727,7 @@ TimelineView::~TimelineView()
 }
 
 //Enable sorting without actually performing it!!!
-void TimelineView::setSortingEnabledNoExec(bool b)
+void TimelineView::setSortingEnabledNoExec(bool /*b*/)
 {
 #if 0
     if(b)
@@ -785,10 +785,10 @@ VInfo_ptr TimelineView::currentSelection()
         return model_->nodeInfo(lst.front());
     }
 #endif
-    return VInfo_ptr();
+    return {};
 }
 
-void TimelineView::setCurrentSelection(VInfo_ptr info)
+void TimelineView::setCurrentSelection(VInfo_ptr /*info*/)
 {
 #if 0
     //While the current is being selected we do not allow
@@ -824,7 +824,7 @@ void TimelineView::slotContextMenu(const QPoint &position)
 }
 
 
-void TimelineView::handleContextMenu(QModelIndex indexClicked,QModelIndexList indexLst,QPoint globalPos,QPoint widgetPos,QWidget *widget)
+void TimelineView::handleContextMenu(QModelIndex indexClicked,QModelIndexList /*indexLst*/,QPoint globalPos,QPoint /*widgetPos*/,QWidget */*widget*/)
 {
     if(!indexClicked.isValid())
         return;
@@ -942,7 +942,7 @@ void TimelineView::slotHzScrollbar(int,int)
         sb->setValue(sb->maximum());
 }
 
-void TimelineView::slotViewCommand(VInfo_ptr info,QString cmd)
+void TimelineView::slotViewCommand(VInfo_ptr /*info*/,QString /*cmd*/)
 {
 }
 
@@ -1160,7 +1160,7 @@ int TimelineView::computeMaxDuration(QString state)
 // Header
 //=========================================
 
-void TimelineView::slotHeaderContextMenu(const QPoint &position)
+void TimelineView::slotHeaderContextMenu(const QPoint &/*position*/)
 {
 }
 
