@@ -1,5 +1,5 @@
 //============================================================================
-// Copyright 2009-2020 ECMWF.
+// Copyright 2009- ECMWF.
 // This software is licensed under the terms of the Apache Licence version 2.0
 // which can be obtained at http://www.apache.org/licenses/LICENSE-2.0.
 // In applying this licence, ECMWF does not waive the privileges and immunities
@@ -11,6 +11,7 @@
 
 #include <QtAlgorithms>
 #include <QApplication>
+#include <QElapsedTimer>
 #include <QHeaderView>
 #include <QPalette>
 #include <QScrollBar>
@@ -354,7 +355,7 @@ void TreeNodeView::slotViewCommand(VInfo_ptr info,QString cmd)
             QGuiApplication::setOverrideCursor(QCursor(Qt::WaitCursor));
 #endif
 #ifdef _UI_TREENODEVIEW_DEBUG
-            QTime t;
+            QElapsedTimer t;
             t.start();
 #endif
             //apply expand in the view
